@@ -17,7 +17,7 @@ EventLogger::EventLogger() : ControlBase("Event Logger","Allows you to see/log a
 		pushSlot(new NullControl(("[ ] "+tmp).c_str(),"Show/hide events from "+tmp));
 	}
 	pushSlot(NULL);
-	pushSlot(new ValueEditControl<unsigned int>("Verbosity","Controls verbosity level: 0=name,type; 1=0+duration,timestamp; 2=1+magnitude; 3=2+subclass info","Please enter a new verbosity level: 0=name,type; 1=0+duration,timestamp; 2=1+magnitude; 3=2+subclass info",&verbosity));
+	pushSlot(new ValueEditControl<unsigned int>("Verbosity","Controls verbosity level: 0=(gen,source,type); 1=0+gen_id,source_id,type_id; 2=1+duration,timestamp; 3=2+magnitude; additional columns may be added for subclass info","Please enter a new verbosity level: 0=(gen,source,type); 1=0+gen_id,source_id,type_id; 2=1+duration,timestamp; 3=2+magnitude; additional columns may be added for subclass info",&verbosity));
 	pushSlot(new ControlBase("[X] Console Output","If selected, outputs events to the console"));
 	pushSlot(new StringInputControl("[ ] File Output","Please enter the filename to log to (in /ms/...)"));
 }
@@ -109,8 +109,8 @@ void EventLogger::checkLogFile() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.16 $
  * $State: Exp $
- * $Date: 2004/11/04 03:01:32 $
+ * $Date: 2004/12/22 23:53:34 $
  */
