@@ -36,7 +36,12 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 	if(slots.size()>1)
 		numlen=(int)(log(slots.size()-1)/log(10))+1;
 #ifdef HelpControl_HTML_
-	sout->printf("<ol>\n");
+	unsigned int ngoodslots=0;
+	for(unsigned int i=0; i<slots.size(); i++)
+		if(slots[i]!=NULL)
+			ngoodslots++;
+	if(ngoodslots>0)
+		sout->printf("<ol>\n");
 #endif
 	for(unsigned int i=0; i<slots.size(); i++) {
 		if(slots[i]==NULL)
@@ -52,7 +57,7 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 		else
 			while(len>0 && !isspace(desc[len-1])) len--;
 #ifdef HelpControl_HTML_
-		fmt="%s<li><!--%*d--><code><b>%s</b>: %s";
+		fmt="%s<li value=\"%*d\"><code><b>%s</b>: %s";
 #else
 		if(config->main.use_VT100)
 			fmt="\33[1m%s%*d. %s\33[0m: %s\n";
@@ -89,7 +94,8 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
 		report(slots[i],pre,depth_remain-1);
 	}
 #ifdef HelpControl_HTML_
-	sout->printf("</ol>\n");
+	if(ngoodslots>0)
+		sout->printf("</ol>\n");
 #endif
 }
 
@@ -98,9 +104,9 @@ void HelpControl::report(ControlBase* r, const std::string& prefix, unsigned int
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/07/14 00:50:26 $
+ * $Date: 2004/11/18 00:04:16 $
  */
 
