@@ -3,21 +3,22 @@
 #include "Motion/EmergencyStopMC.h"
 #include "Motion/MotionSequenceMC.h"
 #include "Motion/LedMC.h"
+#include "SoundPlay/SoundManager.h"
 #include "Events/EventRouter.h"
 #include "ValueEditControl.h"
 #include "NullControl.h"
-#include "SoundPlay/SoundManager.h"
-
-typedef MotionSequenceMC<MotionSequence::SizeSmall> reach_t; //!< just to save some typing
+#include "StringInputControl.h"
+#include "FileInputControl.h"
 
 PostureEditor::PostureEditor(MotionManager::MC_ID estop_ID)
 	: ControlBase("Posture Editor","Allows you to load, save, and numerically edit the posture"), 
 	  pose(), reachID(MotionManager::invalid_MC_ID),
-	  estopID(estop_ID), lastSlot(NULL), loadPose(NULL), savePose(NULL), pauseCalled(false)
+	  estopID(estop_ID), loadPose(NULL), disabledLoadPose(NULL), savePose(NULL), pauseCalled(false)
 {
 	// add load and save menus
 	pushSlot(loadPose=new FileInputControl("Load Posture","Select a posture to open",config->motion.root));
 	loadPose->setFilter("*.pos");
+	disabledLoadPose=new NullControl("[Load disabled by EStop]","Cannot load new postures while EStop is active");
 	pushSlot(savePose=new StringInputControl("Save Posture","Please enter the filename to save to (in "+config->motion.root+")"));
 
 	// add submenu for weight editors
@@ -33,6 +34,12 @@ PostureEditor::PostureEditor(MotionManager::MC_ID estop_ID)
 		pushSlot(new ValueEditControl<float>(outputNames[i],&pose(i).value));
 }
 
+PostureEditor::~PostureEditor() {
+	delete loadPose;
+	delete disabledLoadPose;
+	options[0]=NULL;
+}
+
 ControlBase *
 PostureEditor::activate(MotionManager::MC_ID disp_id, Socket * gui) {
 	//cout << "activate" << endl;
@@ -42,7 +49,7 @@ PostureEditor::activate(MotionManager::MC_ID disp_id, Socket * gui) {
 	for(unsigned int i=LEDOffset; i<LEDOffset+NumLEDs; i++)
 		pose.setOutputCmd(i,0);
 	// add it the motion sequence we'll be using to move to changes
-	SharedObject<reach_t> reach;
+	SharedObject<SmallMotionSequenceMC> reach;
 	reachID=motman->addPersistentMotion(reach);
 	// we'll need to know when estop is turned on or off
 	erouter->addListener(this,EventBase::estopEGID);
@@ -55,29 +62,31 @@ PostureEditor::refresh() {
 	//cout << "refresh" << endl;
 	if(isEStopped()) {
 		erouter->addTimer(this,0,500);
-		options[0]=NULL;
+		options[0]=disabledLoadPose;
 	} else {
 		options[0]=loadPose;
 	}
-	if(lastSlot==loadPose) {
-		// we just got back from the load menu
+	if(loadPose->getLastInput().size()>0) {
 		pose.LoadFile(loadPose->getLastInput().c_str());
 		updatePose(moveTime);
-	} else if(lastSlot==savePose || savePose->getLastInput().size()>0) {
+		loadPose->clearLastInput();
+	} else if(savePose->getLastInput().size()>0) {
 		// we just got back from the save menu
-		pose.SaveFile(config->motion.makePath(savePose->getLastInput()).c_str());
+		std::string filename=savePose->getLastInput();
+		if(filename.find(".")==std::string::npos)
+			filename+=".pos";
+		pose.SaveFile(config->motion.makePath(filename).c_str());
 		savePose->takeInput("");
 	} else {
 		updatePose(moveTime/2);
 	}
-	lastSlot=NULL;
 	pauseCalled=false;
 	ControlBase::refresh();
 }
 
 void
 PostureEditor::pause() {
-	//cout << "paused" << endl;
+	refresh(); //one last time, in case this pause is due to un-estop putting Controller into low-profile mode
 	pauseCalled=true;
 	erouter->removeListener(this,EventBase::timerEGID);
 }
@@ -91,26 +100,18 @@ PostureEditor::deactivate() {
 	ControlBase::deactivate();
 }
 
-ControlBase*
-PostureEditor::doSelect() {
-	// record the option that is being selected, in case it's the load or save
-	lastSlot=options[hilights.front()];
-	// but do what we'd normally do (select that option)
-	return ControlBase::doSelect();
-}
-
 void
 PostureEditor::processEvent(const EventBase& e) {
 	if(e.getGeneratorID()==EventBase::estopEGID) {
 		if(e.getTypeID()==EventBase::deactivateETID) {
-			MMAccessor<reach_t>(reachID)->play();
+			MMAccessor<SmallMotionSequenceMC>(reachID)->play();
 			erouter->removeListener(this,EventBase::timerEGID);
 			if(!pauseCalled)
 				refresh();
 		} else {
 			if(!pauseCalled) {
-				erouter->addTimer(this,0,500);
-				processEvent(EventBase(EventBase::timerEGID,0,EventBase::statusETID));
+				erouter->addTimer(this,0,500); // timer to allow updates on joint positions
+				processEvent(EventBase(EventBase::timerEGID,0,EventBase::statusETID)); // but also do one right now
 			}
 		}
 	} else if(e.getGeneratorID()==EventBase::timerEGID) {
@@ -131,11 +132,11 @@ PostureEditor::isEStopped() {
 void
 PostureEditor::updatePose(unsigned int delay) {
 	bool paused=isEStopped();
-	MMAccessor<reach_t> reach_acc(reachID);
+	MMAccessor<SmallMotionSequenceMC> reach_acc(reachID);
 	reach_acc->clear();
-	reach_acc->setPlayTime(delay);
+	reach_acc->setTime(delay);
 	reach_acc->setPose(pose);
-	reach_acc->setPlayTime(delay+100);
+	reach_acc->advanceTime(100);
 	reach_acc->setPose(pose);
 	if(paused)
 		reach_acc->pause();
@@ -149,8 +150,8 @@ PostureEditor::updatePose(unsigned int delay) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/10/18 19:53:02 $
+ * $Date: 2004/12/21 21:49:50 $
  */
