@@ -6,8 +6,6 @@
 #include "Shared/SharedObject.h"
 #include "Motion/PostureEngine.h"
 #include "Motion/MotionManager.h"
-#include "StringInputControl.h"
-#include "FileInputControl.h"
 #include "Events/EventListener.h"
 
 //! allows logging of events to the console or a file
@@ -16,14 +14,14 @@ public:
 	//! constructor
 	explicit PostureEditor(MotionManager::MC_ID estop_ID);
 
+	//! destructor
+	virtual ~PostureEditor();
+
 	virtual ControlBase * activate(MotionManager::MC_ID disp_id, Socket * gui);
 	virtual void refresh(); //!< if we're back from a child slot, it's either load or save, so we need to handle it
 	virtual void pause();
 	virtual void deactivate();
 
-	//! opens a custom (embedded) menu edit outputs
-	virtual ControlBase* doSelect();
-	
 	//! listens for the EStop to be turned off before moving
 	virtual void processEvent(const EventBase& e);
 	
@@ -32,9 +30,9 @@ protected:
 	MotionManager::MC_ID reachID; //!< id of motion sequence used to slow "snapping" to positions
 	MotionManager::MC_ID estopID; //!< so we can check if the estop is active
 
-	ControlBase* lastSlot; //!< the last accessed slot
-	FileInputControl* loadPose; //!< the control for loading postures
-	StringInputControl* savePose; //!< the control for saving postures
+	class FileInputControl* loadPose; //!< the control for loading postures
+	class NullControl* disabledLoadPose; //!< a message to display instead of loadPose when EStop is on
+	class StringInputControl* savePose; //!< the control for saving postures
 	bool pauseCalled; //!< true if refresh hasn't been called since pause
 	
 	static const unsigned int moveTime=1500; //!< number of milliseconds to take to load a posture - individual joint changes will be done in half the time
@@ -52,10 +50,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/10/18 19:53:02 $
+ * $Date: 2004/12/02 18:48:56 $
  */
 
 #endif
