@@ -16,6 +16,8 @@ class SavePostureControl : public StringInputControl {
 	virtual ControlBase * takeInput(const std::string& msg) {
 		if(msg.size()>0) {
 			std::string filename;
+			if(filename.find(".")==std::string::npos)
+				filename+=".pos";
 			filename=config->motion.makePath(msg);
 			PostureEngine post;
 			post.takeSnapshot();
@@ -30,10 +32,10 @@ class SavePostureControl : public StringInputControl {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/01/30 01:29:41 $
+ * $Date: 2004/12/02 21:29:45 $
  */
 
 #endif
