@@ -19,6 +19,8 @@ class SaveWalkControl : public StringInputControl {
 	virtual ControlBase * takeInput(const std::string& msg) {
 		if(msg.size()>0) {
 			std::string filename=config->motion.makePath(msg);
+			if(filename.find(".")==std::string::npos)
+				filename+=".prm";
 			MotionManager::MC_ID id = (thewalk==NULL ? walk_id : thewalk->getID() );
 			WalkMC* walk=thewalk;
 			if(id!=MotionManager::invalid_MC_ID)
@@ -47,9 +49,9 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/03/26 00:28:41 $
+ * $Date: 2004/12/02 21:29:45 $
  */
 #endif
