@@ -41,8 +41,11 @@ WaypointWalkControl::activate(MotionManager::MC_ID disp_id, Socket * gui) {
 void
 WaypointWalkControl::refresh() {
 	if(saveCtl->getLastInput().size()>0) {
-		sout->printf("Attempting save to %s...\n",saveCtl->getLastInput().c_str());
-		std::string path=config->motion.makePath(saveCtl->getLastInput());
+		std::string filename=saveCtl->getLastInput();
+		if(filename.find(".")==std::string::npos)
+			filename+=".wyp";
+		std::string path=config->motion.makePath(filename);
+		sout->printf("Attempting save to %s...\n",path.c_str());
 		MMAccessor<WaypointWalkMC>(walk_id)->SaveWaypointFile(path.c_str());
 		saveCtl->clearLastInput();
 	}
@@ -244,9 +247,9 @@ ControlBase* WaypointWalkControl::WaypointEditControl::doSelect() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/11/04 03:01:32 $
+ * $Date: 2004/12/02 21:29:45 $
  */
 
