@@ -4,7 +4,7 @@
 #include "Wireless/Socket.h"
 
 const char ASCIIVisionBehavior::charMap[ASCIIVisionBehavior::charMapSize] = {
-	' ','.','\'','`','^','"',',',':',';','~','-','!','i','l','I','>','<','+','?',')',
+	' ','.',',','\'','~','-','"','^',':',';','!','i','l','I','>','+','?',')',
 	'1',']','|','/','t','f','j','r','n','u','v','c','z','x','Y','U','J','C','L','Q',
 	'0','O','Z','X','m','w','q','p','d','b','k','h','a','o','*','#','M','W','&','8',
 	'%','B','$','@'
