@@ -15,8 +15,8 @@ public:
 	//! constructor
 	ASCIIVisionBehavior() : BehaviorBase("ASCIIVisionBehavior") {}
 
-	static const unsigned int charMapSize=64;
-	static const char charMap[charMapSize];
+	static const unsigned int charMapSize=62;  //!< the number of available characters for levels of "gray"
+	static const char charMap[charMapSize]; //!< the included characters sorted in order of darkness - could be improved... (less is more sometimes)
 
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
@@ -42,10 +42,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:35 $
+ * $Date: 2004/12/23 01:47:06 $
  */
 
 #endif
