@@ -21,14 +21,14 @@ class BanditMachine : public StateNode {
 public:
 	//!constructor
 	BanditMachine()
-		: StateNode("BanditMachine","BanditMachine",NULL), stare(NULL), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
+		: StateNode("BanditMachine","BanditMachine"), stare(NULL), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
 	{
 		stare=new StareAtBallBehavior();
 		stare->AddReference();
 	}
 	//!constructor
-	BanditMachine(const char* n, StateNode* p=NULL)
-		: StateNode(n,p), stare(), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
+	BanditMachine(const char* n)
+		: StateNode("BanditMachine",n), stare(), start(NULL), liedown(MotionManager::invalid_MC_ID), bandit(2)
 	{
 		stare=new StareAtBallBehavior();
 		stare->AddReference();
@@ -42,12 +42,12 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 
 	virtual void setup() {
-		StateNode *wait=start=addNode(new WaitNode("Wait",this,bandit));
-		StateNode *left=addNode(new PressNode("Left",this,LFrLegOffset+KneeOffset));
-		StateNode *right=addNode(new PressNode("Right",this,RFrLegOffset+KneeOffset));
-		StateNode *decide=addNode(new DecideNode("Decide",this,bandit,left,right));
-		StateNode *recoverl=addNode(new OutputNode("\nBadPressLeft",this,std::cout,wait));
-		StateNode *recoverr=addNode(new OutputNode("\nBadPressRight",this,std::cout,wait));
+		StateNode *wait=start=addNode(new WaitNode("Wait",bandit));
+		StateNode *left=addNode(new PressNode("Left",LFrLegOffset+KneeOffset));
+		StateNode *right=addNode(new PressNode("Right",RFrLegOffset+KneeOffset));
+		StateNode *decide=addNode(new DecideNode("Decide",bandit,left,right));
+		StateNode *recoverl=addNode(new OutputNode("\nBadPressLeft",std::cout,wait));
+		StateNode *recoverr=addNode(new OutputNode("\nBadPressRight",std::cout,wait));
 		left->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[LFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
 		right->addTransition(new SmoothCompareTrans<float>(wait,&state->pidduties[RFrLegOffset+RotatorOffset],CompareTrans<float>::LT,-.07,EventBase(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID),.7));
 		wait->addTransition(new TimeOutTrans(decide,2000));
@@ -81,18 +81,17 @@ protected:
 	public:
 		//! constructor
 		/*! @param n name of the node
-		 *  @param p the parent node
 		 *  @param idx the joint index of the paw to move
 		 */
-		PressNode(const char* n, StateNode* p, unsigned int idx) : StateNode("PressNode",n,p), press_id(MotionManager::invalid_MC_ID), index(idx) {
-			SharedObject<MotionSequenceMC<MotionSequence::SizeSmall> > press;
-			press->setPlayTime(0);
+		PressNode(const char* n, unsigned int idx) : StateNode("PressNode",n), press_id(MotionManager::invalid_MC_ID), index(idx) {
+			SharedObject<SmallMotionSequenceMC> press;
+			press->setTime(0);
 			press->setOutputCmd(idx,.6);
-			press->setPlayTime(1);
+			press->setTime(1);
 			press->setOutputCmd(idx,.6);
-			press->setPlayTime(200);
+			press->setTime(200);
 			press->setOutputCmd(idx,.3);
-			press->setPlayTime(1500);
+			press->setTime(1500);
 			press->setOutputCmd(idx,outputRanges[idx][MinRange]);
 			press_id=motman->addPersistentMotion(press,MotionManager::kStdPriority+1);
 		}
@@ -102,16 +101,16 @@ protected:
 		}
 		virtual void DoStart() {
 			StateNode::DoStart();
-			MMAccessor<MotionSequenceMC<MotionSequence::SizeSmall> > press(press_id);
+			MMAccessor<SmallMotionSequenceMC> press(press_id);
 			press->play();
 			press->setOutputCmd(index,.6);
-			//			press->setPlaySpeed(1);
+			//			press->setSpeed(1);
 		}
 		virtual void DoStop() {
-			MMAccessor<MotionSequenceMC<MotionSequence::SizeSmall> > press(press_id);
-			//			press->setPlaySpeed(-1);
+			MMAccessor<SmallMotionSequenceMC> press(press_id);
+			//			press->setSpeed(-1);
 			press->pause();
-			press->setPlayTime(0);
+			press->setTime(0);
 			StateNode::DoStop();
 		}
 	protected:
@@ -124,13 +123,12 @@ protected:
 	public:
 		//! constructor
 		/*! @param n name of the node
-		 *  @param p the parent node
 		 *  @param bandito the decision making algorithm to use (look in karmedbandit.h)
 		 *  @param left the PressNode to go to if the left paw is chosen
 		 *  @param right the PressNode to go to if the right paw is chosen
 		 */
-		DecideNode(const char* n, StateNode* p, karmedbanditExp3_1& bandito, StateNode* left, StateNode* right)
-			: StateNode("DecideNode",n,p), b(bandito), l(left), r(right)
+		DecideNode(const char* n, karmedbanditExp3_1& bandito, StateNode* left, StateNode* right)
+			: StateNode("DecideNode",n), b(bandito), l(left), r(right)
 		{}
 		virtual void DoStart() {
 			StateNode::DoStart();
@@ -159,11 +157,10 @@ protected:
 	public:
 		//! constructor
 		/* @param n name to use for the node
-		 * @param p parent node
 		 * @param bandito the class to pass the reward to (if it comes)
 		 */
-		WaitNode(const char* n, StateNode* p, karmedbanditExp3_1& bandito)
-			: StateNode("WaitNode",n,p), b(bandito), reward(false), leds_id(MotionManager::invalid_MC_ID)
+		WaitNode(const char* n, karmedbanditExp3_1& bandito)
+			: StateNode("WaitNode",n), b(bandito), reward(false), leds_id(MotionManager::invalid_MC_ID)
 		{
 			leds_id=motman->addPersistentMotion(SharedObject<LedMC>());
 		}
@@ -217,10 +214,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.20 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.24 $
  * $State: Exp $
- * $Date: 2004/11/11 21:32:14 $
+ * $Date: 2004/12/21 21:49:50 $
  */
 
 #endif
