@@ -25,7 +25,7 @@ DriveMeBehavior::DriveMeBehavior()
     last_dx(0), last_dy(0), last_da(0), last_time(5000)
 {
   // Construct the standing up motion that the aibo does after it's done moving
-  stand->setPlayTime(700); // 700 milliseconds to stand up
+  stand->setTime(700); // 700 milliseconds to stand up
   stand->setPose(PostureEngine("/ms/data/motion/stand.pos"));
 }
 
@@ -60,7 +60,7 @@ void DriveMeBehavior::processEvent(const EventBase& event)
   using namespace std;
 
   WalkMC *walker;
-  MotionSequenceMC<MotionSequence::SizeSmall> *standp;
+  SmallMotionSequenceMC *standp;
 
   // oh, OK, make sure it's a timer event
   if(event.getGeneratorID() != EventBase::timerEGID) return;
@@ -71,7 +71,7 @@ void DriveMeBehavior::processEvent(const EventBase& event)
   motman->checkinMotion(walker_id);
 
   // Stand us up right now.
-  standp = (MotionSequenceMC<MotionSequence::SizeSmall>*)motman->checkoutMotion(stand_id);
+  standp = (SmallMotionSequenceMC*)motman->checkoutMotion(stand_id);
   standp->play();
   motman->checkinMotion(stand_id);
 
@@ -109,9 +109,9 @@ void DriveMeBehavior::processEvent(const EventBase& event)
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:35 $
+ * $Date: 2004/12/21 21:49:50 $
  */
 
