@@ -26,7 +26,7 @@ public:
 protected:
 	MotionManager::MC_ID walker_id; //!< walks
 	MotionManager::MC_ID stand_id;  //!< stands up first
-	SharedObject< MotionSequenceMC<MotionSequence::SizeSmall> > stand; //!< for standing
+	SharedObject<SmallMotionSequenceMC> stand; //!< for standing
 
 	double last_dx; //!< the last dx received
 	double last_dy; //!< the last dy received
@@ -39,10 +39,10 @@ protected:
  * @author tss (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/21 20:29:07 $
  */
 
 #endif
