@@ -75,7 +75,9 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	EventBase head_release, head_lock, clock;
+	EventBase head_release; //!< event template to match to signal the head's PID joints should be relaxed
+	EventBase head_lock;    //!< event template to match to signal the head's PID joints should be powered up again
+	EventBase clock;        //!< event template to match to signal a new round of calculations should be performed
 };
 
 /*! @file
@@ -83,10 +85,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:06 $
  */
 
 #endif
