@@ -87,8 +87,8 @@ public:
 				}
 			
 			//If you would like to verify the positiions of the back toes... (relative to body center)
-			//cout << "L: " << kine->getFrameInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
-			//cout << "R: " << kine->getFrameInterestPoint(BaseFrameOffset,"ToeRBkPaw").t();
+			//cout << "L: " << kine->getJointInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
+			//cout << "R: " << kine->getJointInterestPoint(BaseFrameOffset,"ToeRBkPaw").t();
 			
 		} else {
 			serr->printf("KinematicSampleBehavior: Unhandled event %s\n",e.getName().c_str());
@@ -99,12 +99,13 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
+	//! returns the index of the knee for the requested @a leg
 	unsigned int getIndex(LegOrder_t leg) {
 		//or try: return PawFrameOffset+leg;
 		return LegOffset+leg*JointsPerLeg+KneeOffset;
 	}
-	LegOrder_t lastLeg;
-	MotionManager::MC_ID poseID;
+	LegOrder_t lastLeg; //!< the last leg to have its button pressed, i.e. the "source"
+	MotionManager::MC_ID poseID; //!< the PostureMC which does all the computation
 };
 
 /*! @file
@@ -112,10 +113,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:06 $
  */
 
 #endif
