@@ -66,13 +66,13 @@ public:
 			NEWMAT::ColumnVector obj(4);
 			switch(lastLeg) {
 			case LFrLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerInnerBackLFrThigh,LowerOuterBackLFrThigh"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerInnerBackLFrThigh,LowerOuterBackLFrThigh"); break;
 			case RFrLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerInnerBackRFrThigh,LowerOuterBackRFrThigh"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerInnerBackRFrThigh,LowerOuterBackRFrThigh"); break;
 			case LBkLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerInnerFrontLBkThigh"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerInnerFrontLBkThigh"); break;
 			case RBkLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerInnerFrontRBkThigh"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerInnerFrontRBkThigh"); break;
 			}
 			if(obj(4)!=1)
 				return;
@@ -108,13 +108,13 @@ public:
 			NEWMAT::ColumnVector obj(4);
 			switch(lastLeg) {
 			case LFrLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerLeftBackLFrShin,LowerRightBackLFrShin"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerLeftBackLFrShin,LowerRightBackLFrShin"); break;
 			case RFrLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"LowerLeftBackRFrShin,LowerRightBackRFrShin"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"LowerLeftBackRFrShin,LowerRightBackRFrShin"); break;
 			case LBkLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"ToeLBkPaw"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"ToeLBkPaw"); break;
 			case RBkLegOrder:
-				obj=kine->getFrameInterestPoint(BaseFrameOffset,"ToeRBkPaw"); break;
+				obj=kine->getJointInterestPoint(BaseFrameOffset,"ToeRBkPaw"); break;
 			}
 			if(obj(4)!=1)
 				return;
@@ -139,11 +139,11 @@ public:
 			pose_acc->solveLinkPosition(obj,solveLink,link);
 
 			//If you would like to verify the positiions of the back toes... (relative to body center)
-			//cout << "L: " << kine->getFrameInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
-			//cout << "R: " << kine->getFrameInterestPoint(BaseFrameOffset,"ToeRBkPaw").t();
-			//cout << "Toe: " << pose_acc->getFrameInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
-			//cout << "PawA: " << pose_acc->getFrameInterestPoint(BaseFrameOffset,"LBkPaw").t();
-			//cout << "PawB: " << (pose_acc->frameToFrame(PawFrameOffset+LBkLegOrder,BaseFrameOffset)*Kinematics::pack(0,0,0)).t();
+			//cout << "L: " << kine->getJointInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
+			//cout << "R: " << kine->getJointInterestPoint(BaseFrameOffset,"ToeRBkPaw").t();
+			//cout << "Toe: " << pose_acc->getJointInterestPoint(BaseFrameOffset,"ToeLBkPaw").t();
+			//cout << "PawA: " << pose_acc->getJointInterestPoint(BaseFrameOffset,"LBkPaw").t();
+			//cout << "PawB: " << (pose_acc->jointToJoint(PawFrameOffset+LBkLegOrder,BaseFrameOffset)*Kinematics::pack(0,0,0)).t();
 			
 		} else {
 			serr->printf("KinematicSampleBehavior2: Unhandled event %s\n",e.getName().c_str());
@@ -154,8 +154,8 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	LegOrder_t lastLeg;
-	MotionManager::MC_ID poseID;
+	LegOrder_t lastLeg; //!< the last leg to have its button pressed, i.e. the "source"
+	MotionManager::MC_ID poseID; //!< the PostureMC which does all the computation
 };
 
 /*! @file
@@ -163,10 +163,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:06 $
  */
 
 #endif
