@@ -62,11 +62,22 @@ public:
 		}
 	}
 
-	static std::string getClassDescription() { return "Looking for Sound Behavior Class"; }
+	static std::string getClassDescription() { return "Turns head to sound source, estimated by average volume difference between left and right ears"; }
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	MotionManager::MC_ID mc_id;
+	MotionManager::MC_ID mc_id; //!< the id of the HeadPointerMC which does the looking
 };
 
+/*! @file
+ * @brief Defines LookForSoundBehavior, which turns head to sound source, estimated by average volume difference between left and right ears
+ * @author Paris Smaragdis (paris AT media mit edu) (Creator)
+ *
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
+ * $State: Exp $
+ * $Date: 2004/12/23 01:47:06 $
+ */
+
 #endif
