@@ -17,8 +17,8 @@ public:
 	virtual void DoStart() {
 		BehaviorBase::DoStart(); // do this first
 
-		SharedObject<MotionSequenceMC<MotionSequence::SizeSmall> > ms;
-		ms->setPlayTime(3000);
+		SharedObject<SmallMotionSequenceMC> ms;
+		ms->setTime(3000);
 		ms->setOutputCmd(LFrLegOffset+ElevatorOffset,outputRanges[LFrLegOffset+ElevatorOffset][MaxRange]);
 		ms->setOutputCmd(RFrLegOffset+ElevatorOffset,outputRanges[RFrLegOffset+ElevatorOffset][MaxRange]);
 		ms->setOutputCmd(LBkLegOffset+ElevatorOffset,outputRanges[LBkLegOffset+ElevatorOffset][MaxRange]);
@@ -62,12 +62,12 @@ public:
 
 	void addMS(LegOrder_t leg,unsigned int delay=0) {
 		unsigned int index=leg*JointsPerLeg+RotatorOffset;
-		SharedObject<MotionSequenceMC<MotionSequence::SizeSmall> > ms;
-		ms->setPlayTime(delay);
+		SharedObject<SmallMotionSequenceMC> ms;
+		ms->setTime(delay);
 		ms->setOutputCmd(index,outputRanges[index][MaxRange]);
-		ms->setPlayTime(delay+2000);
+		ms->advanceTime(2000);
 		ms->setOutputCmd(index,outputRanges[index][MinRange]);
-		ms->setPlayTime(delay+4000);
+		ms->advanceTime(4000);
 		ms->setOutputCmd(index,outputRanges[index][MaxRange]);
 		MotionManager::MC_ID id=motman->addPrunableMotion(ms);
 		curMotions.push(id);
@@ -78,8 +78,8 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	LegOrder_t nextLeg;
-	std::queue<MotionManager::MC_ID> curMotions;
+	LegOrder_t nextLeg; //!< the next leg to start moving
+	std::queue<MotionManager::MC_ID> curMotions; //!< a queue of IDs of SmallMotionSequenceMC's
 };
 
 /*! @file
@@ -87,10 +87,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
