@@ -10,7 +10,8 @@
 #include "Shared/SharedObject.h"
 
 
-//! Uses kinematics to track the paw which last received a button press with the camera
+//! Uses CMPack kinematics to track the paw which last received a button press with the camera
+/*! This is the "old" way of doing things, using CMPack kinematics... compare to StareAtPawBehavior2 for new-style kinematics */
 class StareAtPawBehavior : public BehaviorBase {
 public:
 	//! constructor
@@ -82,20 +83,20 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	LegOrder_t lastLeg;
-	MotionManager::MC_ID pointID;
-	double head_angles[JointsPerLeg];
+	LegOrder_t lastLeg; //!< last leg to have it's button pressed, i.e. the one we are looking at
+	MotionManager::MC_ID pointID; //!< the HeadPointerMC we are using to do the looking
+	double head_angles[JointsPerLeg]; //!< temporary storage of the head angles we desire
 };
 
 /*! @file
- * @brief Defines StareAtPawBehavior, which uses kinematics to track the paw which last received a button press with the camera
+ * @brief Defines StareAtPawBehavior, which uses CMPack kinematics to track the paw which last received a button press with the camera
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
