@@ -13,7 +13,7 @@
 #include "Motion/Kinematics.h"
 
 
-//! Uses kinematics to track the paw which last received a button press with the camera
+//! Uses new-style ROBOOP kinematics to track the paw which last received a button press with the camera
 class StareAtPawBehavior2 : public BehaviorBase {
 public:
 	//! constructor
@@ -27,10 +27,10 @@ public:
 		erouter->addListener(this,EventBase::sensorEGID);
 		erouter->addListener(this,EventBase::buttonEGID);
 		if(state->robotDesign == WorldState::ERS7Mask)
-			cout << "NOTICE: The ERS-7 has a rather \"sticky\" nod joint\n"
-					 << "(the upper tilt joint).  This can cause it to hesitate\n"
-					 << "or altogether fail to precisely center the target position\n"
-					 << "vertically in the center of the image...\n" << endl;
+			sout->printf("NOTICE: The ERS-7 has a rather \"sticky\" nod joint\n"
+									 "(the upper tilt joint).  This can cause it to hesitate\n"
+									 "or altogether fail to precisely center the target position\n"
+									 "vertically in the center of the image...\n");
 	}
 
 	virtual void DoStop() {
@@ -61,18 +61,17 @@ public:
 
 		} else if(e.getGeneratorID()==EventBase::sensorEGID) {
 
-			//Find paw location
-			const char * ipname=(lastLeg==LFrLegOrder?"ToeLFrPaw":"ToeRFrPaw");
-			NEWMAT::ColumnVector Pobj=kine->getFrameInterestPoint(BaseFrameOffset,ipname);
+			//Which paw do we want?
+			const char * ipname= (lastLeg==LFrLegOrder) ? "ToeLFrPaw" : "ToeRFrPaw";
+
+			//Ask kinematics for current location of that paw (this is the "objective" aka target)
+			NEWMAT::ColumnVector Pobj=kine->getJointInterestPoint(BaseFrameOffset,ipname);
+
+			//Now point the head there
+			MMAccessor<HeadPointerMC>(pointID)->lookAtPoint(Pobj(1),Pobj(2),Pobj(3)); //keep head as far away as possible
+			//Alternative method:
+			// MMAccessor<HeadPointerMC>(pointID)->lookAtPoint(Pobj(1),Pobj(2),Pobj(3),80); //keep head 80mm away
 
-			//Compute neck angles
-			PostureEngine pose;
-			NEWMAT::ColumnVector Plink=Kinematics::pack(0,0,1,0); //infinite ray along z axis - maximize distance from paw
-			//NEWMAT::ColumnVector Plink=Kinematics::pack(0,0,80,1); //or, keep head 8cm away from paw
-			pose.solveLinkVector(Pobj,CameraFrameOffset,Plink);
-			
-			//Set joint values
-			MMAccessor<HeadPointerMC>(pointID)->setJoints(pose(HeadOffset+0).value,pose(HeadOffset+1).value,pose(HeadOffset+2).value);
 		} else {
 			serr->printf("StareAtPawBehavior2: Unhandled event %s\n",e.getName().c_str());
 		}
@@ -82,19 +81,19 @@ public:
 	virtual std::string getDescription() const { return getClassDescription(); }
 	
 protected:
-	LegOrder_t lastLeg;
-	MotionManager::MC_ID pointID;
+	LegOrder_t lastLeg; //!< last leg to have it's button pressed, i.e. the one we are looking at
+	MotionManager::MC_ID pointID; //!< the HeadPointerMC we are using to do the looking
 };
 
 /*! @file
- * @brief Defines StareAtPawBehavior2, which uses kinematics to track the paw which last received a button press with the camera
+ * @brief Defines StareAtPawBehavior2, which uses new-style ROBOOP kinematics to track the paw which last received a button press with the camera
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:36 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
