@@ -14,7 +14,7 @@ protected:
 
 public:
   //! constructor
-  HeadPointerNode(std::string nodename="HeadPointerNode") : 
+  HeadPointerNode(const std::string & nodename="HeadPointerNode") : 
     StateNode("HeadPointerNode",nodename), head_mc(), head_id(MotionManager::invalid_MC_ID) {}
 
   //! activate the node
@@ -45,7 +45,7 @@ public:
 
 protected:
   //! constructor
-  HeadPointerNode(std::string &classname, std::string &nodename) : 
+  HeadPointerNode(const std::string &classname, const std::string &nodename) : 
     StateNode(classname,nodename), head_mc(), head_id(MotionManager::invalid_MC_ID) {}
 
 
@@ -55,11 +55,11 @@ protected:
  * @brief Defines HeadPointerNode, a simple StateNode that runs a HeadPointerMC motion command and throws a status event upon completion
  * @author dst (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.5 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/11/17 01:31:06 $
+ * $Date: 2004/12/04 00:10:42 $
  */
 
 #endif
