@@ -7,14 +7,15 @@
 #include <ostream>
 
 //! A very simple StateNode that outputs its name to a given ostream upon activation, handy for debugging
+/*! The Event Logger controller item (Status Reports menu) is a much better tool for debugging */
 class OutputNode : public StateNode {
 public:
 	//!constructor, sets name and ostream to use for output
-	OutputNode(const char* nm, StateNode* par, ostream& output) : StateNode("OutputNode",nm,par), next(NULL), out(output), msg(nm) {}
+	OutputNode(const char* nm, ostream& output) : StateNode("OutputNode",nm), next(NULL), out(output), msg(nm) {}
 	//!constructor, sets name and another state which will immediately be transitioned to upon activation
-	OutputNode(const char* nm, StateNode* par, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm,par), next(nextstate), out(output), msg(nm) {}
+	OutputNode(const char* nm, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm), next(nextstate), out(output), msg(nm) {}
 	//!constructor, sets name, message, and another state which will immediately be transitioned to upon activation
-	OutputNode(const char* nm, const std::string& mg, StateNode* par, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm,par), next(nextstate), out(output), msg(mg) {}
+	OutputNode(const char* nm, const std::string& mg, ostream& output, StateNode * nextstate) : StateNode("OutputNode",nm), next(nextstate), out(output), msg(mg) {}
 
 	//!outputs this state's name, will transition to #next if non-NULL
 	/*!if #next is NULL, the state will simply stay active until some other transition causes it to leave*/
@@ -42,10 +43,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 20:35:00 $
+ * $Date: 2004/12/04 00:10:42 $
  */
 
 #endif
