@@ -11,25 +11,19 @@
 class WalkNode : public StateNode {
 public:
 	//!constructor
-	WalkNode(StateNode * p=NULL)
-		: StateNode("WalkNode",p), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(0), y(0), a(0)
-	{
-		setRetain(false);
-	}
+	WalkNode()
+		: StateNode("WalkNode"), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(0), y(0), a(0)
+	{}
 
 	//!constructor, positive @a yvel is counter-clockwise from above (to match coordinate system)
-	WalkNode(float xvel, float yvel, float avel, StateNode * p=NULL)
-		: StateNode("WalkNode",p), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(xvel), y(yvel), a(avel)
-	{
-		setRetain(false);
-	}
+	WalkNode(float xvel, float yvel, float avel)
+		: StateNode("WalkNode"), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(xvel), y(yvel), a(avel)
+	{}
 
 	//!constructor, positive @a yvel is counter-clockwise from above (to match coordinate system)
-	WalkNode(const std::string& name, float xvel, float yvel, float avel, StateNode * p=NULL)
-		: StateNode("WalkNode",name,p), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(xvel), y(yvel), a(avel)
-	{
-		setRetain(false);
-	}
+	WalkNode(const std::string& name, float xvel, float yvel, float avel)
+		: StateNode("WalkNode",name), walkid(MotionManager::invalid_MC_ID), walkidIsMine(true), x(xvel), y(yvel), a(avel)
+	{}
 
 	//! sets the velocity of the walk
 	void setVelocity(float xvel, float yvel, float avel) {
@@ -117,10 +111,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2004/11/11 20:35:00 $
+ * $Date: 2004/12/04 00:10:42 $
  */
 
 #endif
