@@ -2,6 +2,7 @@
 #include "StateNode.h"
 #include "Wireless/Wireless.h"
 #include "SoundPlay/SoundManager.h"
+#include "Events/EventRouter.h"
 
 /*! @deprecated, use the version of the constructor where you can pass a name */
 Transition::Transition() : BehaviorBase("Transition"), srcs(), dsts(), sound() {}
@@ -28,6 +29,8 @@ void Transition::fire() {
 	if(sound.size()!=0)
 		sndman->PlayFile(sound);
 
+	erouter->postEvent(EventBase::stateTransitionEGID,reinterpret_cast<int>(this),EventBase::statusETID,0,getName(),1);
+
 	for(unsigned int i=0; i<srcs.size(); i++)
 		if(srcs[i]->isActive()) //It's usually a bad idea to call DoStop/DoStart when it's already stopped/started...
 			srcs[i]->DoStop();
@@ -60,9 +63,9 @@ std::string Transition::getName() const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/11/11 20:34:59 $
+ * $Date: 2004/12/17 05:51:32 $
  */
 
