@@ -9,13 +9,15 @@
 //! causes a transition when at least @e n sources have signalled completion;  @e n = 0 means "all" (default)
 class CompletionTrans : public Transition {
 protected:
-  int minsrcs;
+  int minsrcs; //!< the minimum number of sources which must signal completion before this transition will fire
   bool *completions;  //!< pointer to array for recording completion events for all sources
 
 public:
+	//! constructor, pass @a destination and the minimum number of sources which must signal completion before this transition will fire
   CompletionTrans(StateNode* destination, int n=0) :
     Transition("CompletionTrans",destination), minsrcs(n), completions(NULL) {};
 
+	//! constructor, pass @a name, @a destination and the minimum number of times the source must signal completion beyond the first (@a n)
   CompletionTrans(const std::string& name, StateNode* destination, int n=0) :
     Transition("CompletionTrans",name,destination), minsrcs(n), completions(NULL) {};
 
@@ -70,10 +72,10 @@ protected:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/11/15 22:46:19 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
