@@ -9,12 +9,14 @@
 
 class EventTrans : public Transition {
 private:
-  int argcount;
-  EventBase::EventGeneratorID_t egid;
-  unsigned int esid;
-  EventBase::EventTypeID_t etid;
+  int argcount; //!< the number of arguments which were supplied to the constructor (granularity of filtering)
+  EventBase::EventGeneratorID_t egid; //!< the requested generator
+  unsigned int esid; //!< the requested source
+  EventBase::EventTypeID_t etid; //!< the requested type
 
 public:
+	//!@name Constructors
+	//! follows general pattern of EventRouter::addListener()
   EventTrans(StateNode* destination, EventBase::EventGeneratorID_t gid)
 		: Transition("EventTrans",destination), argcount(1), egid(gid), esid(0), etid(EventBase::statusETID)
 	{}
@@ -38,6 +40,7 @@ public:
   EventTrans(const std::string& name, StateNode* destination, EventBase::EventGeneratorID_t gid, unsigned int sid, EventBase::EventTypeID_t tid)
 		: Transition("EventTrans",name,destination), argcount(3), egid(gid), esid(sid), etid(tid)
 	{}
+	//@}
 
   //! starts listening
   virtual void DoStart() {
@@ -65,10 +68,10 @@ public:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/11/15 22:46:19 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
