@@ -12,7 +12,8 @@ public:
   NullTrans(StateNode* destination) : Transition("NullTrans",destination) {}
 	
   //! constructor
-  NullTrans(const std::string& name, StateNode* destination) : Transition("NullTrans",name,destination) {}
+  NullTrans(const std::string& name, StateNode* destination) : 
+    Transition("NullTrans",name,destination) {}
 	
   //!starts 0 msec timer, so transition will occur very soon
   virtual void DoStart() {
@@ -25,6 +26,13 @@ public:
 
   //!when timer event is received, fire() the transition
   virtual void processEvent(const EventBase&) { fire(); }
+
+protected:
+	//! constructor, only to be called by subclasses (which need to specify their own @a classname)
+  NullTrans(const std::string &classname, const std::string &instancename, 
+	    StateNode* destination) :
+    Transition(classname,instancename,destination) {}
+
 };
 
 /*! @file
@@ -32,10 +40,10 @@ public:
  * @author dst (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/11/15 22:46:19 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
