@@ -16,7 +16,7 @@ class SmoothCompareTrans : public CompareTrans<T> {
 public:
 	//! constructor, see SmoothCompareTrans class notes for information
   SmoothCompareTrans(StateNode* destination, const T* monitor, typename SmoothCompareTrans<T>::Test_t test, const T& value, const EventBase& poll, float gammap=0)
-		: CompareTrans<T>("SmoothCompareTrans",destination,&avg,test,value,poll), avg(*monitor), realmon(monitor),
+		: CompareTrans<T>("SmoothCompareTrans","SmoothCompareTrans",destination,&avg,test,value,poll), avg(*monitor), realmon(monitor),
 		burnin((unsigned int)(1/(1-gammap))), tests(0), g(gammap)
 	{ }
 
@@ -73,10 +73,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2004/11/15 22:46:19 $
+ * $Date: 2004/12/14 03:24:57 $
  */
 
 #endif
