@@ -20,15 +20,8 @@
  */
 class EventGeneratorBase : public BehaviorBase {
 public:
-	//!@name Constructors
-	//!
-	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid)
-		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(false), isListening(false), srcGenID(EventBase::unknownEGID), srcSourceID(0)
-	{}
-	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid)
-		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(true), isListening(false), srcGenID(srcgid), srcSourceID(srcsid)
-	{}
-	//@}
+	// Constructors are all protected - doesn't make sense to
+	// instantiate this class directly, you want to use a subclass
 
 	//! destructor - does nothing
 	virtual ~EventGeneratorBase() {}
@@ -65,6 +58,22 @@ public:
 	virtual void unsetAutoListen();
 
 protected:
+	//!@name Constructors
+	//!
+	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid)
+		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(false), isListening(false), srcGenID(EventBase::unknownEGID), srcSourceID(0)
+	{}
+	EventGeneratorBase(const std::string& name, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid)
+		: BehaviorBase(name), myGenID(mgid), mySourceID(msid), autoListen(true), isListening(false), srcGenID(srcgid), srcSourceID(srcsid)
+	{}
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid)
+		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(false), isListening(false), srcGenID(EventBase::unknownEGID), srcSourceID(0)
+	{}
+	EventGeneratorBase(const std::string& classname, const std::string& instancename, EventBase::EventGeneratorID_t mgid, unsigned int msid,EventBase::EventGeneratorID_t srcgid, unsigned int srcsid)
+		: BehaviorBase(classname,instancename), myGenID(mgid), mySourceID(msid), autoListen(true), isListening(false), srcGenID(srcgid), srcSourceID(srcsid)
+	{}
+	//@}
+
 	EventBase::EventGeneratorID_t myGenID; //!< the generator ID to broadcast on
 	unsigned int mySourceID;     //!< the source ID to broadcast on
 	bool autoListen;          //!< if true, will automatically start listening for EventBase(genID,sourceID) events
@@ -78,10 +87,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/11/11 01:45:37 $
+ * $Date: 2004/12/20 21:47:59 $
  */
 
 #endif
