@@ -99,26 +99,26 @@ void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t e
 	bool hadListener=hasListeners(egid);
 	listeners.addMapping(el,egid); 
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
 	bool hadListener=hasListeners(egid);
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		listeners.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=hasListeners(egid);
 	listeners.addMapping(el,egid,sid,etid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::addListener(EventListener* el, const EventBase& e) {
 	if(e.getGeneratorID()==EventBase::timerEGID)
@@ -127,9 +127,9 @@ void EventRouter::addListener(EventListener* el, const EventBase& e) {
 		bool hadListener=hasListeners(e.getGeneratorID());
 		listeners.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
 		if(!hadListener)
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID));
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 	}
 }
 
@@ -145,9 +145,9 @@ void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_
 			return; //nothing was removed, don't want to clean up or throw an event
 		listeners.clean(egid);
 		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 	}
 }
 void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
@@ -161,9 +161,9 @@ void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_
 			return; //nothing was removed, don't want to clean up or throw an event
 		listeners.clean(egid);
 		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 	}
 }
 void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
@@ -175,9 +175,9 @@ void EventRouter::removeListener(EventListener* el, EventBase::EventGeneratorID_
 			return; //nothing was removed, don't want to clean up or throw an event
 		listeners.clean(egid);
 		if(!hasListeners(egid))
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+			postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 	}
 }
 void EventRouter::removeListener(EventListener* el, const EventBase& e) {
@@ -188,9 +188,9 @@ void EventRouter::removeListener(EventListener* el, const EventBase& e) {
 			return; //nothing was removed, don't want to clean up or throw an event
 		listeners.clean(e.getGeneratorID());
 		if(!hasListeners(e.getGeneratorID()))
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID));
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
 		else
-			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+			postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 	}
 }
 
@@ -202,18 +202,18 @@ void EventRouter::addTrapper(EventTrapper* el, const EventBase& e) {
 	bool hadListener=hasListeners(e.getGeneratorID());
 	trappers.addMapping(el,e.getGeneratorID(),e.getSourceID(),e.getTypeID());
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::activateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
 	bool hadListener=hasListeners(egid);
 	trappers.addMapping(el,egid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
@@ -221,18 +221,18 @@ void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egi
 	for(unsigned int et=0; et<EventBase::numETIDs; et++)
 		trappers.addMapping(el,egid,sid,(EventBase::EventTypeID_t)et);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
 void EventRouter::addTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
 	bool hadListener=hasListeners(egid);
 	trappers.addMapping(el,egid,sid,etid);
 	if(!hadListener)
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::activateETID,0,EventBase::EventGeneratorNames[egid],1));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 
 /*! Note that since timers are not broadcast, they cannot be trapped.  Only the EventListener which requested the timer will receive that timer. */
@@ -247,18 +247,18 @@ void EventRouter::removeTrapper(EventTrapper* el, const EventBase& e) {
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(e.getGeneratorID());
 	if(!hasListeners(e.getGeneratorID()))
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::deactivateETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,e.getGeneratorID(),EventBase::statusETID,0,EventBase::EventGeneratorNames[e.getGeneratorID()],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid) {
 	if(!trappers.removeMapping(el,egid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid) {
 	int removed=0;
@@ -268,18 +268,18 @@ void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 void EventRouter::removeTrapper(EventTrapper* el, EventBase::EventGeneratorID_t egid, unsigned int sid, EventBase::EventTypeID_t etid) {
 	if(!trappers.removeMapping(el,egid,sid,etid))
 		return; //nothing was removed, don't want to clean up or throw an event
 	trappers.clean(egid);
 	if(!hasListeners(egid))
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::deactivateETID,0,EventBase::EventGeneratorNames[egid],0));
 	else
-		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID));
+		postEvent(new EventBase(EventBase::erouterEGID,egid,EventBase::statusETID,0,EventBase::EventGeneratorNames[egid],1));
 }
 
 void EventRouter::removeTrapper(EventTrapper* el) {
@@ -532,10 +532,10 @@ bool EventRouter::EventMapper::verifyMapping(void * listener, EventBase::EventGe
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/10/07 22:14:17 $
+ * $Date: 2004/12/22 23:12:59 $
  */
 
 
