@@ -10,7 +10,7 @@ class FilterBankEvent : public EventBase {
 public:
 	//! constructor
 	FilterBankEvent(FilterBankGenerator* creator,EventBase::EventGeneratorID_t gid,unsigned int sid)
-		: EventBase(gid,sid,EventBase::statusETID), src(creator)
+		: EventBase(gid,sid,EventBase::statusETID,0,creator->getName(),1), src(creator)
 	{}
 
 	//! Gives access to underlying generator
@@ -58,10 +58,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/12/22 23:12:59 $
  */
 
 #endif
