@@ -2,17 +2,18 @@
 #ifndef INCLUDED_DynamicMotionSequenceMC_h_
 #define INCLUDED_DynamicMotionSequenceMC_h_
 
-#include "MotionSequenceMC.h"
+#include "MotionSequenceEngine.h"
+#include "MotionCommand.h"
 #include <vector>
 
 //! Uses STL's vector for dynamic memory allocation - don't use this as a motion command, pointers in shared memory regions can be invalid in other processes
-/*! See MotionSequenceMC for documentation on its members */
-class DynamicMotionSequence : public MotionSequence {
+/*! See MotionSequenceEngine for documentation on its members */
+class DynamicMotionSequence : public MotionCommand, public MotionSequenceEngine {
 public:
 	//!constructor
-	DynamicMotionSequence() : MotionSequence(), moves(), erased() {clear();}
+	DynamicMotionSequence() : MotionCommand(), MotionSequenceEngine(), moves(), erased() {clear();}
 	//!constructor, loads from a file and then resets the playtime to beginning and begins to play
-	explicit DynamicMotionSequence(const char* filename) : MotionSequence(), moves(), erased() {clear();LoadFile(filename);setPlayTime(1);}
+	explicit DynamicMotionSequence(const char* filename) : MotionCommand(), MotionSequenceEngine(), moves(), erased() {clear();LoadFile(filename);setPlayTime(1);}
 	//!destructor
 	virtual ~DynamicMotionSequence() {}
 
@@ -30,8 +31,11 @@ public:
 	}*/
 	
 
+	virtual int isDirty() { return isPlaying(); }
+	virtual int isAlive() { return (playspeed>0) ? (playtime<=endtime) : (playtime>0); }
+	
 	virtual int updateOutputs() {
-		MotionSequence::updateOutputs();
+		MotionSequenceEngine::updateOutputs();
 		if(!isPlaying()) {
 			for(unsigned int i=0; i<NumOutputs; i++) //just copies getOutputCmd(i) across frames
 				motman->setOutput(this,i,getOutputCmd(i));
@@ -112,10 +116,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:27:22 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/12/21 22:39:01 $
  */
 
 #endif
