@@ -50,27 +50,42 @@ public:
 	//! Directly set a single neck joint value
 	/*! @param i joint offset relative to HeadOffset (i.e. one of TPROffset_t)
 	 *  @param value the value to be assigned to join @a i, in radians */
-	void setJointValue(unsigned int i, float value) { headTargets[i]=clipAngularRange(HeadOffset+i,value); 	markDirty(); }
+	void setJointValue(unsigned int i, float value) {
+		if(!ensureValidJoint(i))
+			return;
+		headTargets[i]=clipAngularRange(HeadOffset+i,value);
+		markDirty();
+	}
 	
 	//! Returns the target value of joint @a i.  Use this if you want to know the current @b commanded joint value; To get the current joint @b position, look in WorldState::outputs
 	/*! @param i joint offset relative to HeadOffset (i.e. one of TPROffset_t) */
-	float getJointValue(unsigned int i) const { return headTargets[i]; }
+	float getJointValue(unsigned int i) const {
+		if(ensureValidJoint(i))
+			return headTargets[i];
+		else
+			return 0;
+	}
 	
 	//! Centers the camera on a point in space, attempting to keep the camera as far away from the point as possible
-	/*! @param x location in millimeters
+	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset)
+	 *  @param x location in millimeters
 	 *  @param y location in millimeters
-	 *  @param z location in millimeters */
+	 *  @param z location in millimeters
+	 *
+	 *  @todo this method is an approximation, could be more precise, and perhaps faster, although this is pretty good. */
 	bool lookAtPoint(float x, float y, float z);
 	
 	//! Centers the camera on a point in space, attempting to move the camera @a d millimeters away from the point
-	/*! @param x location in millimeters
+	/*! Point should be relative to the body reference frame (see ::BaseFrameOffset)
+	 *  @param x location in millimeters
 	 *  @param y location in millimeters
 	 *  @param z location in millimeters
 	 *  @param d target distance from point in millimeters */
 	bool lookAtPoint(float x, float y, float z, float d);
 	
 	//! Points the camera in a given direction
-	/*! @param x component of the direction vector
+	/*! Vector should be relative to the body reference frame (see ::BaseFrameOffset)
+	 *  @param x component of the direction vector
 	 *  @param y component of the direction vector
 	 *  @param z component of the direction vector */
 	bool lookInDirection(float x, float y, float z);
@@ -108,6 +123,12 @@ public:
 	 *  the head isn't where it's supposed to be, it won't jerk around */
 	void markDirty();
 
+	//! Makes sure @a i is in the range (0,NumHeadJoints).  If it is instead in the range (HeadOffset,HeadOffset+NumHeadJoints), output a warning and reset @a i to the obviously intended value.
+	/*! @param[in] i joint offset relative to either HeadOffset (i.e. one of TPROffset_t) or 0
+	 *  @param[out] i joint offset relative to HeadOffset (i.e. one of TPROffset_t)
+	 *  @return true if the intended joint could be ascertained, false otherwise */
+	static bool ensureValidJoint(unsigned int& i);
+
 	bool dirty;                          //!< true if a change has been made since last call to updateJointCmds()
 	bool targetReached;                  //!< false if the head is still moving towards its target
   float headTargets[NumHeadJoints];    //!< stores the target value of each joint
@@ -121,10 +142,10 @@ public:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.14 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.18 $
  * $State: Exp $
- * $Date: 2004/10/14 23:02:53 $
+ * $Date: 2004/12/23 00:59:03 $
  */
 
 #endif
