@@ -54,8 +54,10 @@ Kinematics::init() {
 				tkout+=NumOutputs;
 				if((unsigned int)tkout>=NumReferenceFrames)
 					serr->printf("WARNING Kinematics::init(): invalid tekkotsu_frame %d on chain %d (%s), link %d (%s)\n",tkout,i,section.c_str(),l,link.c_str());
-				else
+				else {
 					jointMaps[tkout]=JointMap(i,l);
+					chainMaps[i][l]=tkout;
+				}
 			}
 		}
 	}
@@ -97,7 +99,7 @@ Kinematics::init() {
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::frameToBase(unsigned int j) {
+Kinematics::jointToBase(unsigned int j) {
 	unsigned int c=-1U,l=-1U;
 	if(!lookup(j,c,l)) {
 		NEWMAT::Matrix A(4,4);
@@ -121,7 +123,7 @@ Kinematics::linkToBase(unsigned int j) {
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::baseToFrame(unsigned int j) {
+Kinematics::baseToJoint(unsigned int j) {
 	unsigned int c=-1U,l=-1U;
 	if(!lookup(j,c,l)) {
 		NEWMAT::Matrix A(4,4);
@@ -145,7 +147,7 @@ Kinematics::baseToLink(unsigned int j) {
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::frameToFrame(unsigned int ij, unsigned int oj) {
+Kinematics::jointToJoint(unsigned int ij, unsigned int oj) {
 	unsigned int ci=-1U,li=-1U,co=-1U,lo=-1U;
 	if(ij==oj || !lookup(ij,ci,li) || !lookup(oj,co,lo)) {
 		NEWMAT::Matrix A(4,4);
@@ -170,9 +172,9 @@ Kinematics::frameToFrame(unsigned int ij, unsigned int oj) {
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::frameToLink(unsigned int ij, unsigned int oj) {
+Kinematics::jointToLink(unsigned int ij, unsigned int oj) {
 	unsigned int ci=-1U,li=-1U,co=-1U,lo=-1U;
-	if(ij==oj || !lookup(ij,ci,li) || !lookup(oj,co,lo)) {
+	if(!lookup(ij,ci,li) || !lookup(oj,co,lo)) {
 		NEWMAT::Matrix A(4,4);
 		A<<ROBOOP::fourbyfourident;
 		A.Release(); return A;
@@ -195,9 +197,9 @@ Kinematics::frameToLink(unsigned int ij, unsigned int oj) {
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::linkToFrame(unsigned int ij, unsigned int oj) {
+Kinematics::linkToJoint(unsigned int ij, unsigned int oj) {
 	unsigned int ci=-1U,li=-1U,co=-1U,lo=-1U;
-	if(ij==oj || !lookup(ij,ci,li) || !lookup(oj,co,lo)) {
+	if(!lookup(ij,ci,li) || !lookup(oj,co,lo)) {
 		NEWMAT::Matrix A(4,4);
 		A<<ROBOOP::fourbyfourident;
 		A.Release(); return A;
@@ -267,11 +269,11 @@ Kinematics::getInterestPoint(const std::string& name, unsigned int& c, unsigned
 }
 
 NEWMAT::ReturnMatrix
-Kinematics::getFrameInterestPoint(unsigned int frame, const std::string& name) {
+Kinematics::getJointInterestPoint(unsigned int joint, const std::string& name) {
 	NEWMAT::ColumnVector ans(4);
 	ans=0;
 	unsigned int co=-1U,lo=-1U;
-	if(!lookup(frame,co,lo)) {
+	if(!lookup(joint,co,lo)) {
 		ans.Release(); return ans;
 	}
 	for(unsigned int pos=0,len=0; pos<name.size(); pos+=len+1) {
@@ -308,7 +310,7 @@ LegOrder_t
 Kinematics::findUnusedLeg(const NEWMAT::ColumnVector& down) {
 	float height[NumLegs]; //not actually the real height, but proportional to it, which is all we need
 	for(unsigned int i=0; i<NumLegs; i++) {
-		height[i]=NEWMAT::DotProduct(frameToBase(PawFrameOffset+i).SubMatrix(1,3,4,4),down.SubMatrix(1,3,1,1));
+		height[i]=NEWMAT::DotProduct(jointToBase(PawFrameOffset+i).SubMatrix(1,3,4,4),down.SubMatrix(1,3,1,1));
 		//cout << "height["<<i<<"]=="<<height[i]<<endl;
 	}
 	
@@ -334,9 +336,9 @@ Kinematics::calculateGroundPlane(const NEWMAT::ColumnVector& down) {
 	//Fit a plane to the remaining 3 feet
 	NEWMAT::Matrix legs(3,3);
 	for(unsigned int i=0; i<highleg; i++)
-		legs.Column(i+1)=frameToBase(PawFrameOffset+i).SubMatrix(1,3,4,4);
+		legs.Column(i+1)=jointToBase(PawFrameOffset+i).SubMatrix(1,3,4,4);
 	for(unsigned int i=highleg+1; i<NumLegs; i++)
-		legs.Column(i)=frameToBase(PawFrameOffset+i).SubMatrix(1,3,4,4);
+		legs.Column(i)=jointToBase(PawFrameOffset+i).SubMatrix(1,3,4,4);
 	//cout << legs;
 	NEWMAT::ColumnVector ones(3); ones=1;
 	NEWMAT::ColumnVector p(4);
@@ -376,7 +378,7 @@ Kinematics::projectToPlane(unsigned int j, const NEWMAT::ColumnVector& r_j,
 	 *  Of course, if @f$p_{xyz} \cdot r@f$ is 0, then r and p are parallel
 	 *  (since @a p_j is the normal of the plane, so a line perpendicular to
 	 *  the normal is parallel to the plane), so we set the resulting
-	 *  homogenous coordinates accordingly to represent an interesection at
+	 *  homogeneous coordinates accordingly to represent an interesection at
 	 *  infinity. */
 
 	float denom=0;
@@ -410,10 +412,10 @@ Kinematics::update(unsigned int c, unsigned int l) {
  * @brief 
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.19 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.23 $
  * $State: Exp $
- * $Date: 2004/10/28 23:06:10 $
+ * $Date: 2004/12/21 23:51:18 $
  */
 
