@@ -29,49 +29,50 @@ namespace ROBOOP {
  *  in ::state.
  *
  *  To perform kinematics on a hypothetical set of joint values,
- *  please see PostureEngine or its subclasses.  PostureEngine also
- *  includes inverse kinematic functions, which will allow you to
+ *  use PostureEngine or one of its subclasses.  PostureEngine also
+ *  adds inverse kinematic functions, which will allow you to
  *  determine joint angles in order to reach a given point.
  *  
  *  The underlying ROBOOP library does not currently handle branching
  *  kinematic chains - in other words, each limb of the robot is a
- *  separate Robot as far as ROBOOP is concerned.  This class
- *  interfaces the Tekkotsu array index approach to referencing joints
- *  with ROBOOP's chain based hierarchy.
+ *  separate ROBOOP::Robot as far as ROBOOP is concerned.  This
+ *  Kinematics class interfaces the Tekkotsu array index approach to
+ *  referencing joints with ROBOOP's chain based hierarchy.
  *  
- *  Thus, wherever a link or reference frame index is requested, you
- *  can simply supply one of the output indexes in the usual manner:
- *  @code kine->frameToBase(HeadOffset+TiltOffset); @endcode
+ *  Thus, wherever a reference frame index is requested, you can
+ *  simply supply one of the output indexes in the usual manner:
+ *  @code kine->jointToBase(HeadOffset+TiltOffset); @endcode
  *
  *  However, there are also a number of points on the body which are
  *  not joints, but should have their own reference frames, such as
  *  the base frame, or the camera.  These frames have their own
  *  indices, listed in the robot info file for the model in question
  *  (such as ERS7Info.h), with names ending in @c FrameOffset.
- *  @code kine->frameToBase(CameraFrameOffset); @endcode
+ *  @code kine->jointToBase(CameraFrameOffset); @endcode
+ *  Note that for these non-joint-associated reference frames, the
+ *  link and joint frames are always identical, so you can use either
+ *  version of the corresponding functions.
  *
  *  Since newmat matrix library is used by ROBOOP, you will need to
- *  pass and receive information in newmat matrices.  This class
- *  provides #pack and #unpack functions which can convert individual
- *  x,y,z variables into a NEWMAT::ColumnVector, and vice versa.
- *  However, for readability of your code and long-term ease of use,
- *  we recommend embracing the newmat data structures directly when
- *  appropriate.
+ *  pass and receive information in newmat matrices.  Kinematics class
+ *  provides static #pack and #unpack functions which can convert
+ *  individual x,y,z variables into a NEWMAT::ColumnVector, and vice
+ *  versa.  However, for readability of your code and long-term ease
+ *  of use, we recommend embracing the newmat data structures directly
+ *  when appropriate.
  *  @code
  *  // Find the ray from the camera to whatever the near-field IR is hitting:
- *  // x and y will be in the range -1 to 1 for resolution layer independence
- *  // This ignores lens distortion - just proof of concept
- *  NEWMAT::Matrix T = kine->frameToFrame(NearIRFrameOffset,CameraFrameOffset);
+ *  NEWMAT::Matrix T = kine->jointToJoint(NearIRFrameOffset,CameraFrameOffset);
  *  NEWMAT::ColumnVector camera_ray = T*Kinematics::pack(0,0,state->sensors[NearIRDistOffset]);
- *  float x=atan(camera_ray(1),camera_ray(3))/config->vision.horizFOV/2;
- *  float y=atan(camera_ray(2),camera_ray(3))/config->vision.vertFOV/2;
+ *  float x,y; // x and y will be in the range -1 to 1 for resolution layer independence
+ *  config->vision.computePixel(x,y,camera_ray(1),camera_ray(2),camera_ray(3));
  *  @endcode
  *  
- *  Finally, for each model we have created a database of "interest points",
+ *  Finally, for each model we have created a database of "interest points" --
  *  locations of notable interest on the body of the robot.  These may be of
  *  use to people attempting to use the limbs to manipulate objects.
- *  To access these interest points, simply call either #getLinkInterestPoint
- *  or #getFrameInterestPoint with the name of the interest point, obtained
+ *  To access these interest points, call either #getLinkInterestPoint
+ *  or #getJointInterestPoint with the name of the interest point, obtained
  *  from the <a href="http://www.tekkotsu.org/Kinematics.html">diagrams</a>.
  *
  *  Note that you can pass a comma separated list of interest point names
@@ -79,6 +80,37 @@ namespace ROBOOP {
  *  @code kine->getLinkInterestPoint(BaseFrameOffset,"LowerInnerFrontLFrShin,LowerOuterFrontLFrShin"); @endcode
  *  
  *  @see PostureEngine for inverse kinematics
+ *
+ *
+ *
+ *  <a name="config_file_format"></a><h2>Configuration File Format</h2>
+ *
+ *  The file is actually read by ROBOOP::Config, and thus the syntax
+ *  of the file is defined by that class.  However, Tekkotsu will look
+ *  for some additional sections beyond what is expected by ROBOOP.
+ *
+ *  In any give link section, a <tt>tekkotsu_output</tt> field may
+ *  appear, which specifies the index (aka offset) of the
+ *  corresponding joint in Tekkotsu, as defined by the model's Info.h
+ *  file (e.g. ERS7Info.h).  Alternatively, <tt>tekkotsu_frame</tt>
+ *  may be specified, which should specify the offset of an abstract
+ *  reference frame, which does not correspond to any joint.
+ *  Typically this is used for things such as the camera, or
+ *  un-actuated joints, such as the spring-loaded ankles.
+ *
+ *  Additionally, Kinematics will look for an custom
+ *  <tt>InterestPoints</tt> section, which should contain a
+ *  <tt>Length</tt> field for specifying the number of interest
+ *  points.  Kinematics will then attempt to read
+ *  <tt>%InterestPoint</tt><i>N</i> for 1 through <i>Length</i>.
+ * 
+ *  Each <tt>%InterestPoint</tt><i>N</i> section should contain:
+ *  - <tt>name</tt> - (string) name which will be passed to get*InterestPoint() to retrieve this IP
+ *  - <tt>chain</tt> - (string) name of the chain the IP is in, must match one of the kinematic chains loaded from the file
+ *  - <tt>link</tt> - (unsigned int) the index of the link the IP is connected to
+ *  - <tt>x</tt> - (float) the x location of the point, in link-relative coordinates
+ *  - <tt>y</tt> - (float) the y location of the point, in link-relative coordinates
+ *  - <tt>z</tt> - (float) the z location of the point, in link-relative coordinates
  */
 class Kinematics {
 public:
@@ -92,66 +124,66 @@ public:
 
 
 
-	//! Returns a matrix for transforming from link @a j to base frame
-	/*! @param[in]  j the link number, see class notes for values */
-	NEWMAT::ReturnMatrix linkToBase(unsigned int j);
+	//! Returns a matrix for transforming from link frame @a j to base frame
+	/*! @param[in]  link the output offset, see class notes for values */
+	NEWMAT::ReturnMatrix linkToBase(unsigned int link);
 
-	//! Returns a matrix for transforming from frame @a j to base frame
-	/*! @param[in]  j the frame number, see class notes for values */
-	NEWMAT::ReturnMatrix frameToBase(unsigned int j);
+	//! Returns a matrix for transforming from joint frame @a j to base frame
+	/*! @param[in]  joint the output offset, see class notes for values */
+	NEWMAT::ReturnMatrix jointToBase(unsigned int joint);
 
-	//! Returns a matrix for transforming from the base frame to link @a j
-	/*! @param[in]  j the link number, see class notes for values */
-	NEWMAT::ReturnMatrix baseToLink(unsigned int j);
+	//! Returns a matrix for transforming from the base frame to link @a j frame
+	/*! @param[in]  link the output offset, see class notes for values */
+	NEWMAT::ReturnMatrix baseToLink(unsigned int link);
 
-	//! Returns a matrix for transforming from the base frame to frame @a j
-	/*! @param[in]  j the frame number, see class notes for values */
-	NEWMAT::ReturnMatrix baseToFrame(unsigned int j);
+	//! Returns a matrix for transforming from the base frame to joint @a j frame
+	/*! @param[in]  joint the output offset, see class notes for values */
+	NEWMAT::ReturnMatrix baseToJoint(unsigned int joint);
 
-	//! Returns a matrix for transforming from link @a ij to link @a oj frame
-	/*! @param[in]  ij the link number to convert from, see class notes for values
-	 *  @param[in]  oj the link number to convert to, see class notes for values */
-	NEWMAT::ReturnMatrix linkToLink(unsigned int ij, unsigned int oj);
+	//! Returns a matrix for transforming from link @a ij to link @a oj
+	/*! @param[in]  iL the output offset to convert from, see class notes for values
+	 *  @param[in]  oL the output offset to convert to, see class notes for values */
+	NEWMAT::ReturnMatrix linkToLink(unsigned int iL, unsigned int oL);
 
-	//! Returns a matrix for transforming from link @a ij to frame @a oj
-	/*! @param[in]  ij the link number to convert from, see class notes for values
-	 *  @param[in]  oj the frame number to convert to, see class notes for values */
-	NEWMAT::ReturnMatrix linkToFrame(unsigned int ij, unsigned int oj);
+	//! Returns a matrix for transforming from link frame @a ij to joint frame @a oj
+	/*! @param[in]  iL the output offset to convert from, see class notes for values
+	 *  @param[in]  oJ the output offset to convert to, see class notes for values */
+	NEWMAT::ReturnMatrix linkToJoint(unsigned int iL, unsigned int oJ);
 
-	//! Returns a matrix for transforming from frame @a ij to link @a oj
-	/*! @param[in]  ij the frame number to convert from, see class notes for values
-	 *  @param[in]  oj the link number to convert to, see class notes for values */
-	NEWMAT::ReturnMatrix frameToLink(unsigned int ij, unsigned int oj);
+	//! Returns a matrix for transforming from joint frame @a ij to link frame @a oj
+	/*! @param[in]  iJ the output offset to convert from, see class notes for values
+	 *  @param[in]  oL the output offset to convert to, see class notes for values */
+	NEWMAT::ReturnMatrix jointToLink(unsigned int iJ, unsigned int oL);
 
-	//! Returns a matrix for transforming from frame @a ij to frame @a oj frame
-	/*! @param[in]  ij the frame number to convert from, see class notes for values
-	 *  @param[in]  oj the frame number to convert to, see class notes for values */
-	NEWMAT::ReturnMatrix frameToFrame(unsigned int ij, unsigned int oj);
+	//! Returns a matrix for transforming from joint @a ij to joint @a oj
+	/*! @param[in]  iJ the output offset to convert from, see class notes for values
+	 *  @param[in]  oJ the output offset to convert to, see class notes for values */
+	NEWMAT::ReturnMatrix jointToJoint(unsigned int iJ, unsigned int oJ);
 
 
 
 	//! Returns the location of a named point and the link it is attached to
 	/*! @param[in]  name   the name of the interest point; varies by model, <a href="http://www.tekkotsu.org/Kinematics.html">see the diagrams</a> for your model.
-	 *  @param[out] j      on exit, joint index of the link, or -1U if not found
-	 *  @param[out] ip     on exit, a homogenous column vector of the requested point
+	 *  @param[out] link   on exit, offset of the link, or -1U if not found
+	 *  @param[out] ip     on exit, a homogeneous column vector of the requested point, relative to the link frame returned in @a j
 	 *
 	 *  If @a name is not found, j will be -1 and ip will be all 0's. */
-	void getInterestPoint(const std::string& name, unsigned int& j, NEWMAT::Matrix& ip);
+	void getInterestPoint(const std::string& name, unsigned int& link, NEWMAT::Matrix& ip);
 
-	//! Returns the location of a named point, relative to any desired reference frame
-	/*! @param[in]  frame  the desired reference frame to give results in
+	//! Returns the location of a named point, relative to any desired joint reference frame
+	/*! @param[in]  joint  the desired joint reference frame to give results in
 	 *  @param[in]  name   the name of the interest point; varies by model, <a href="http://www.tekkotsu.org/Kinematics.html">see the diagrams</a> for your model.
 	 *
 	 *  You can pass a comma separated list of interest point names and the result will be the midpoint of those IPs */
-	NEWMAT::ReturnMatrix getFrameInterestPoint(unsigned int frame, const std::string& name);
+	NEWMAT::ReturnMatrix getJointInterestPoint(unsigned int joint, const std::string& name);
 
 	//! Returns the location of a named point, relative to any desired reference frame
-	/*! @param[in]  link   the desired link frame to give results in
+	/*! @param[in]  link   the desired link reference frame to give results in
 	 *  @param[in]  name   the name of the interest point; varies by model, <a href="http://www.tekkotsu.org/Kinematics.html">see the diagrams</a> for your model.
 	 *
 	 *  You can pass a comma separated list of interest point names and the result will be the midpoint of those IPs */
 	NEWMAT::ReturnMatrix getLinkInterestPoint(unsigned int link, const std::string& name) {
-		NEWMAT::ColumnVector p=frameToLink(link,link)*getFrameInterestPoint(link,name);
+		NEWMAT::ColumnVector p=jointToLink(link,link)*getJointInterestPoint(link,name);
 		p.Release(); return p;
 	}
 
@@ -176,13 +208,13 @@ public:
 
 	//! Find the point of intersection between a ray and a plane
 	/*! @param j is the link number the ray is relative to
-	 *  @param r_j is the line through the origin, in homogenous coordinates
+	 *  @param r_j is the line through the origin, in homogeneous coordinates
 	 *  @param b is the link number the plane is relative to (probably BaseFrameOffset)
 	 *  @param p_b represents the plane to be intersected
 	 *  @param f is the link number the results should be relative to
 	 *
 	 *  @a p_b should be of the form @f$p_1x + p_2y + p_3z = p_4@f$
-	 *  @return homogenous coordinate of intersection (may be infinity) */
+	 *  @return homogeneous coordinate of intersection (may be infinity) */
 	NEWMAT::ReturnMatrix projectToPlane(unsigned int j, const NEWMAT::ColumnVector& r_j,
 	                                    unsigned int b, const NEWMAT::ColumnVector& p_b,
 	                                    unsigned int f);
@@ -217,6 +249,7 @@ public:
 		ox=m(1,1); oy=m(2,1); oz=m(3,1); oh=m(4,1);
 	}
 	
+	//! returns the global ROBOOP::Config object which Kinematics classes initialize themselves from (#roconfig)
 	static ROBOOP::Config * getConfig() { return roconfig; }
 	
 protected:
@@ -227,7 +260,7 @@ protected:
 	/*! @param[in]  name   the name of the interest point; varies by model, <a href="http://www.tekkotsu.org/Kinematics.html">see the diagrams</a> for your model.
 	 *  @param[out] c      on exit, chain index the IP is on
 	 *  @param[out] l      on exit, link index the IP is on
-	 *  @param[out] ip     on exit, a homogenous column vector of the requested point
+	 *  @param[out] ip     on exit, a homogeneous column vector of the requested point
 	 *
 	 *  If @a name is not found, @a c and @a l will be -1 and @a ip will be all 0's. 
 	 *  This internal version of the function allows us to use @a c and @a l, ourselves,
@@ -263,14 +296,14 @@ protected:
 	//! A separate ROBOOP::Robot instantiation for each chain since ROBOOP package doesn't support branching chains (which would be rather difficult to implement well)
 	std::vector<ROBOOP::Robot*> chains;
 
-	//! holds mapping for each chain's links back to the tekkotsu outputs they represent
+	//! holds mapping for each chain's links back to the tekkotsu outputs and reference frames they represent
 	std::vector< std::vector<unsigned int> > chainMaps;
 	
 	//! Allows mapping from tekkotsu output index to chain and link indicies
 	struct JointMap {
 		JointMap() : chain(-1U), link(-1U) {} //!< constructor
 		JointMap(unsigned int c, unsigned int l) : chain(c), link(l) {} //!< constructor
-		unsigned int chain; //! the chain index
+		unsigned int chain; //!< the chain index
 		unsigned int link; //!< the link index
 	};
 	//! holds the position and attached link of a given interest point
@@ -317,10 +350,10 @@ extern Kinematics * kine;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.23 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2004/10/19 17:06:31 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
