@@ -20,12 +20,17 @@ class LedMC : public MotionCommand, public LedEngine {
   //! destructor
   virtual ~LedMC() {}
   
+	virtual void DoStart() {
+		MotionCommand::DoStart();
+		dirty=true;
+	}
+
   //! updates the cmds from LedEngine::updateLEDs()
   virtual int updateOutputs() {
     updateLEDFrames(cmds);
     for(unsigned int i=0; i<NumLEDs; i++)
       if(cmds[i][0].weight!=0)
-	motman->setOutput(this,i+LEDOffset,cmds[i]);
+				motman->setOutput(this,i+LEDOffset,cmds[i]);
     if (nextFlashEnd < (unsigned int)-1)  // do we have a flash in progress?
       notified=false;
     else if (notified == false) {  // flash has ended (nextFlashEnd == -1), but notice not yet sent
@@ -56,11 +61,11 @@ protected:
  * @brief Defines LedMC, which provides a basic MotionCommand wrapper to LedEngine
  * @author ejt (Creator)
  *
- * $Author: dst $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.7 $
+ * $Author: ejt $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/09/10 22:25:15 $
+ * $Date: 2004/12/17 05:52:36 $
  */
 
 #endif
