@@ -542,6 +542,7 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 	//cout << "addMotion()NOW: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
 	cmdlist[mc_id].lastAccessor=_MMaccID;
 	cmdlist[mc_id].priority=priority;
+	//cout << "setAdd(" << mc_id << ")" << endl;
 	mc->setAdd(mc_id);
 	OStatus err;
 	/*{
@@ -551,10 +552,14 @@ MotionManager::doAddMotion(const SharedObjectBase& sm, bool autoprune, float pri
 		}
 		ASSERT((int)i==subjs[_MMaccID]->NumberOfObservers(),"did I miss an observer?");
 	}*/
-	ASSERT((err=subjs[_MMaccID]->SetData(sm.getRegion()))==oSUCCESS,"*** ERROR MotionManager: SetData returned " << err);
+	//cout << "Sent at " << get_time() << flush;
+	err=subjs[_MMaccID]->SetData(sm.getRegion());
+	ASSERT(err==oSUCCESS,"*** ERROR MotionManager: SetData returned " << err);
 	//cout << "addMotion()afterSetData: sm.getRegion()->NumberOfReference()==" << sm.getRegion()->NumberOfReference() << endl;
-	ASSERT((err=subjs[_MMaccID]->NotifyObservers())==oSUCCESS,"*** ERROR MotionManager: NotifyObservers returned " << err);
+	err=subjs[_MMaccID]->NotifyObservers();
+	ASSERT(err==oSUCCESS,"*** ERROR MotionManager: NotifyObservers returned " << err);
 	//	cout << "addMotion-done" << endl;
+	//cout << " - " << get_time() << endl;
 	return func_end(mc_id);
 }
 
@@ -563,6 +568,7 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 	//	cout << "receivedMsg..." << flush;
 	func_begin();
 	//	cout << id << "..." << flush;
+	//cout << "Received at " << get_time() << endl;
 	for(int x=0; x<event.NumOfData(); x++) {
 		RCRegion * rcr = event.RCData(x);
 		MotionManagerMsg * mminfo = reinterpret_cast<MotionManagerMsg*>(rcr->Base());
@@ -575,13 +581,25 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 			cmdlist[mc_id].rcr[_MMaccID]=rcr;
 			//should be able to do a nice dynamic cast instead of a static one
 			// but it gives NULL for some reason - i blame having to do the fork trick
+			//cout << "Adding mc_id=="<< mc_id << " (and dynamic_cast is still " << dynamic_cast<MotionCommand*>(mminfo) << ")" << endl;
 			cmdlist[mc_id].baseaddrs[_MMaccID]=static_cast<MotionCommand*>(mminfo);
-			erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::activateETID,0));
 			cmdlist[mc_id].baseaddrs[_MMaccID]->DoStart();
+			erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::activateETID,0));
 		} break;
 		case MotionManagerMsg::deleteMotion: {
 			//cout << "deleteMotion(): cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
-			cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
+			//cout << "deleting mc_id=="<<mc_id << endl;
+			if(cmdlist[mc_id].rcr[_MMaccID]==NULL)
+				cout << "WARNING: MotionManager attempted to delete a NULL motion! mc_id="<<mc_id<<" _MMaccID=" << _MMaccID << endl;
+			else {
+				checkoutMotion(mc_id,true);
+				cmdlist[mc_id].baseaddrs[_MMaccID]->DoStop();
+				erouter->postEvent(new EventBase(EventBase::motmanEGID,mc_id,EventBase::deactivateETID,0));
+				cmdlist[mc_id].rcr[_MMaccID]->RemoveReference();
+				cmdlist[mc_id].rcr[_MMaccID]=NULL;
+				push_free(mc_id);
+				checkinMotion(mc_id);
+			}
 			//cout << "deleteMotion()NOW: cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mc_id].rcr[_MMaccID]->NumberOfReference() << endl;
 		} break;
 		default:
@@ -636,20 +654,17 @@ MotionManager::removeMotion(MC_ID mcid) {
 	if(mcid==invalid_MC_ID)
 		return;
 	func_begin();
-	checkoutMotion(mcid,true);
-	cmdlist[mcid].baseaddrs[_MMaccID]->DoStop();
-	erouter->postEvent(new EventBase(EventBase::motmanEGID,mcid,EventBase::deactivateETID,0));
 #ifdef PLATFORM_APERIOS
 	MotionManagerMsg dmsg;
 	dmsg.setDelete(mcid);
+	//cout << "Remove at " << get_time() << flush;
 	subjs[_MMaccID]->SetData(&dmsg,sizeof(dmsg));
 	subjs[_MMaccID]->NotifyObservers();
+	//cout << " - " << get_time() << endl;
 	//cout << "removeMotion(): cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
 	cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
 	//cout << "removeMotion()NOW: cmdlist[mcid].rcr[_MMaccID]->NumberOfReference()==" << cmdlist[mcid].rcr[_MMaccID]->NumberOfReference() << endl;
 #endif //PLATFORM_APERIOS
-	push_free(mcid);
-	checkinMotion(mcid);
 	func_end();
 }
 
@@ -748,10 +763,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.38 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.39 $
  * $State: Exp $
- * $Date: 2004/10/17 01:16:11 $
+ * $Date: 2004/12/04 00:11:34 $
  */
 
 
