@@ -34,7 +34,6 @@ public:
 	 * These are also not virtual - otherwise you'd have to still check the motion out and it would make
 	 * this all pointless! @return @c *this */
 	PostureMC& setDirty(bool d=true) { dirty=d; return *this; } 
-	bool isDirty() const {return dirty;} //!< if you want to check the dirty flag
 	virtual PostureMC& setTolerance(float t) { tolerance=t; return *this; } //!< sets #tolerance, returns @c *this
 	virtual float getTolerance() { return tolerance; } //!< returns #tolerance
 	//@}
@@ -60,6 +59,7 @@ public:
 		tmp.takeSnapshot(); 
 		return (maxdiff(tmp)>tolerance);
 	}
+	virtual void DoStart() { MotionCommand::DoStart(); dirty=true; } //!< marks this as dirty each time it is added
 	//@}
 
 	//!Had to override stuff to manage a dirty flag
@@ -92,10 +92,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/08/30 20:26:45 $
+ * $Date: 2004/12/21 00:42:21 $
  */
 
 #endif
