@@ -59,13 +59,7 @@ const vector3d WalkMC::max_accel_xya(MAX_DX*2,MAX_DY*2,MAX_DA*2);
 unsigned int checksum(const char *data,int num); //!< computes a file checksum
 
 WalkMC::WalkMC(const char* pfile/*=NULL*/)
-	// tss "SmoothWalk" modification follows
-	//	: MotionCommand(), isPaused(false), wp(), body_loc(), body_angle(),
-	//		pos_delta(0,0,0), angle_delta(0), travelTime(get_time()),
-	//		time(get_time()), TimeStep(FrameTime), vel_xya(0,0,0),
-	//		target_vel_xya(0,0,0)
-
-	: MotionCommand(), isPaused(false), wp(), cp(), body_loc(), body_angle(),
+	: MotionCommand(), isPaused(false), wp(), cp(), body_loc(), body_angle(), acc_style(DEFAULT_ACCEL), step_count(-1), last_cycle(0),
 				pos_delta(0,0,0), angle_delta(0), travelTime(get_time()),
 				time(get_time()), TimeStep(FrameTime), slowmo(1.0f),
 				CycleOffset(0), TimeOffset(0), NewCycleOffset(false),
@@ -131,12 +125,14 @@ void WalkMC::init(const char* pfile)
 int WalkMC::isDirty()
 {
   if(isPaused)
-		return false;
+		return 0;
+	if(step_count==0)
+		return 0;
   if((target_vel_xya.x == 0) && (target_vel_xya.y == 0) && (target_vel_xya.z == 0)) {
 		// we may stopping, but not stopped yet...
 		return ((vel_xya.x != 0) || (vel_xya.y != 0) || (vel_xya.z != 0));
   }
-  return true;
+  return JointsPerLeg*NumLegs;
 }
 // tss "SmoothWalk" addition ends
 
@@ -251,7 +247,7 @@ unsigned int WalkMC::SaveFile(const char* filename) const {
 	return LoadSave::SaveFile(config->motion.makePath(filename).c_str());
 }
 
-void WalkMC::setTargetVelocity(double dx,double dy,double da)
+void WalkMC::setTargetVelocity(double dx,double dy,double da,int n)
 {
 #ifdef BOUND_MOTION
   da = bound(da, -cp.rotate_max_vel, cp.rotate_max_vel);
@@ -268,8 +264,21 @@ void WalkMC::setTargetVelocity(double dx,double dy,double da)
   target_vel_xya.set(dx,dy,da);
 	// we just modified the target velocity, but we'll hold off on generating
 	// an event until the changes are actually picked up by the motion system
+
+	step_count=n;
 }
 
+void WalkMC::setTargetDisplacement(double dx, double dy, double da, unsigned int n) {
+	if(n==0) {
+		setTargetVelocity(0,0,0,0);
+	} else {
+		double vx=dx/(n*wp.period/1000.0);
+		double vy=dy/(n*wp.period/1000.0);
+		double va=da/(n*wp.period/1000.0);
+		setTargetVelocity(vx,vy,va,n); //apply new value
+	}
+}
+	
 int WalkMC::updateOutputs() {
 	//	cout << "WalkMC,,," << flush;
 	if(!isDirty())
@@ -304,13 +313,15 @@ int WalkMC::updateOutputs() {
 		else
 			applyCalibration(cp.f_calibration,target_vel_xya,cal_target_vel_xya);
 
-  //software accel:
-	vel_xya.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*tm, vel_xya.x+max_accel_xya.x*tm);
-  vel_xya.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*tm, vel_xya.y+max_accel_xya.y*tm);
-  vel_xya.z = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
-	//no software accel:
-	//vel_xya=cal_target_vel_xya;
-	//<end>
+	if(step_count<0 && (acc_style==CALIBRATION_ACCEL || acc_style==DEFAULT_ACCEL && !config->motion.inf_walk_accel)) {
+		//software accel:
+		vel_xya.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*tm, vel_xya.x+max_accel_xya.x*tm);
+		vel_xya.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*tm, vel_xya.y+max_accel_xya.y*tm);
+		vel_xya.z = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
+	} else {
+		//no software accel:
+		vel_xya=cal_target_vel_xya;
+	}
 
   BodyPosition delta;
   delta.loc.set(vel_xya.x*tm,vel_xya.y*tm,0);
@@ -346,7 +357,36 @@ int WalkMC::updateOutputs() {
 
 // tss "SmoothWalk" modification follows
 		// double cycle = (double)(time % wp.period) / wp.period;
+		AdjustedTime = time + TimeOffset + (int)(frame*TimeStep*slowmo);
 		double cycle = (double)(AdjustedTime % wp.period) / wp.period;
+
+		if(step_count>0) {
+			float ncyc=cycle;
+			if(cycle<last_cycle)
+				ncyc+=1;
+			for(unsigned int i=0; i<NumLegs; i++){
+				float midstep = (wp.leg[i].down_time+wp.leg[i].lift_time)/2;
+				//cout << "leg "<<i<<": " <<AdjustedTime << ' ' << cycle << ' ' << last_cycle << ' ' << midstep << ' ' <<step_count ;
+				if(last_cycle<midstep && midstep<=ncyc) { //we just completed a step
+					step_count--;
+					//cout << " -> " << step_count << endl;
+					if(step_count==0) { //we're done, copy out any completed frames
+						for(unsigned int f=0; f<frame; f++)
+							for(unsigned int joint=LegOffset; joint<LegOffset+NumLegJoints; joint++)
+								motman->setOutput(this,joint,cmds[joint][f],f);
+						CycleOffset = AdjustedTime % wp.period;
+						NewCycleOffset = true;
+						last_cycle=cycle;
+						//		cout << "WalkMC-done" << endl;
+						return frame==0?0:NumLegs*JointsPerLeg;
+					}
+					break; //don't count legs moving in sync as two steps, only ever one step at a time
+				}
+				//cout << endl;
+			}
+		}
+		
+
 		double sway   = wp.sway*cos(2*M_PI*cycle);
 		double hop    = wp.hop*sin(4*M_PI*cycle);
 		double height = wp.body_height;
@@ -385,15 +425,19 @@ int WalkMC::updateOutputs() {
 					*/
 					tm = wp.period/1000.0 * 0.75; //wtf is the 0.75 based on?  Don't ask me, i just work here! (ejt)
 					vector3d vfp;
-					//software accel:
-					vfp.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*tm, vel_xya.x+max_accel_xya.x*tm);
-					vfp.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*tm, vel_xya.y+max_accel_xya.y*tm);
-					double vfa   = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
-					//no software accel:
-					//vfp.x=cal_target_vel_xya.x;
-					//vfp.y=cal_target_vel_xya.y;
-					//double vfa=cal_target_vel_xya.z;
-					//<end>
+					double vfa;
+					if(step_count<0 && (acc_style==CALIBRATION_ACCEL || acc_style==DEFAULT_ACCEL && !config->motion.inf_walk_accel)) {
+						//software accel:
+						vfp.x = bound(cal_target_vel_xya.x, vel_xya.x-max_accel_xya.x*tm, vel_xya.x+max_accel_xya.x*tm);
+						vfp.y = bound(cal_target_vel_xya.y, vel_xya.y-max_accel_xya.y*tm, vel_xya.y+max_accel_xya.y*tm);
+						vfa   = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
+					} else {
+						//no software accel:
+						vfp.x=cal_target_vel_xya.x;
+						vfp.y=cal_target_vel_xya.y;
+						vfa=cal_target_vel_xya.z;
+					}
+					
 					vfp.z = 0.0;
 					double b = (wp.period/1000.0) * (1.0 - air_f) / 2.0;
 					vector3d target;
@@ -454,7 +498,12 @@ int WalkMC::updateOutputs() {
 				else {
 					if(wp.useDiffDrive) {
 						tm = wp.period/1000.0 * 0.75; //wtf is the 0.75 based on?  Don't ask me, i just work here! (ejt)
-						double vfa   = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
+						double vfa;
+						if(step_count<0 && (acc_style==CALIBRATION_ACCEL || acc_style==DEFAULT_ACCEL && !config->motion.inf_walk_accel)) {
+							vfa   = bound(cal_target_vel_xya.z, vel_xya.z-max_accel_xya.z*tm, vel_xya.z+max_accel_xya.z*tm);
+						} else {
+							vfa   = cal_target_vel_xya.z;
+						}
 						legpos[i] -= delta.loc*dir;
 						float rot = vfa/cp.max_vel[CalibrationParam::rotate]*TimeStep * slowmo / 1000;
 						if((i&1)==0)
@@ -469,10 +518,10 @@ int WalkMC::updateOutputs() {
 			GetLegAngles(nextlegangles,legpos[i],nextpos,i);
 			for(unsigned int j=0; j<JointsPerLeg; j++)
 				cmds[LegOffset+i*JointsPerLeg+j][frame].set(nextlegangles[j]);
+
 		}
 
-		// tss "SmoothWalk" modification follows
-		AdjustedTime = time+TimeOffset+(int)(frame*TimeStep*slowmo);
+		last_cycle=cycle;
 	}
 	
 	for(unsigned int joint=LegOffset; joint<LegOffset+NumLegJoints; joint++)
@@ -544,9 +593,9 @@ void WalkMC::applyCalibration(const float mat[3][11], const vector3d& in, vector
  * @verbinclude CMPack_license.txt
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.29 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.30 $
  * $State: Exp $
- * $Date: 2004/07/24 03:10:59 $
+ * $Date: 2004/12/20 21:26:24 $
  */
 
