@@ -312,6 +312,9 @@ void* Config::setValue(section_t section, const char *key, const char *value,
       } else if (strncasecmp(key,"max_head_roll_speed",29)==0) {
 				motion.max_head_roll_speed=atof(value);
 				return &motion.max_head_roll_speed;
+      } else if (strncasecmp(key,"inf_walk_accel",29)==0) {
+        motion.inf_walk_accel = atoi(value);
+        return &motion.inf_walk_accel;
       } else if (strncasecmp(key,"console_port",29)==0) {
         motion.console_port = atoi(value);
         return &motion.console_port;
@@ -530,9 +533,9 @@ bool Config::extractBool(const char * value) {
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.40 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.41 $
  * $State: Exp $
- * $Date: 2004/11/12 22:07:39 $
+ * $Date: 2004/12/20 21:27:11 $
  */
 
