@@ -92,6 +92,18 @@ class Config {
 			r_z=1;
 		}
       
+		//!provides a pixel hit in image by a ray going through the camera frame
+		/*! Hopefully we'll eventually upgrade this to account for lens distortion
+		 *  @param[in] r_x x value of the ray
+		 *  @param[in] r_y y value of the ray
+		 *  @param[in] r_z z value of the ray
+		 *  @param[out] x x position in range [-1,1]
+		 *  @param[out] y y position in range [-1,1] */
+		void computePixel(float r_x, float r_y, float r_z, float& x, float& y) {
+			x=r_x/(r_z*tan(horizFOV/2));
+			y=r_y/(r_z*tan(vertFOV/2));
+		}
+      
 		//!constructor
 		vision_config() : white_balance(3), gain(2), shutter_speed(2), resolution(2), horizFOV(0), vertFOV(0), focal_length(0), thresh(), colors(), rawcam_port(0), rawcam_transport(0), rle_port(0), rle_transport(0), obj_port(0), restore_image(true), jpeg_dct_method(JDCT_IFAST), rawcam_encoding(ENCODE_COLOR), rawcam_channel(0), rawcam_compression(COMPRESS_NONE), rawcam_compress_quality(75), rawcam_y_skip(0), rawcam_uv_skip(0), rlecam_skip(1), rlecam_channel(0), rlecam_compression(COMPRESS_RLE) {}
 	} vision;
@@ -153,6 +165,7 @@ class Config {
 		float max_head_tilt_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
 		float max_head_pan_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
 		float max_head_roll_speed; //!< max speed for the head joints, used by HeadPointerMC; rad/s
+		bool inf_walk_accel; //!< if true, walks should attempt to switch directions immediately; otherwise they should do some kind of software acceleration to more smoothly switch direction
 		int console_port;  //!< port to send/receive "console" information on (separate from system console)
 		int stderr_port;   //!< port to send error information to
 
@@ -169,7 +182,7 @@ class Config {
 		//!constructor
 		motion_config()
 			: root(), walk(), kinematics(), kinematic_chains(), max_head_tilt_speed(0),
-				max_head_pan_speed(0), max_head_roll_speed(0), console_port(0), stderr_port(0)
+				max_head_pan_speed(0), max_head_roll_speed(0), inf_walk_accel(false), console_port(0), stderr_port(0)
 		{
 			estop_on_snd[0]=estop_off_snd[0]='\0';
 			for(unsigned int i=0; i<NumPIDJoints; i++)
@@ -203,9 +216,10 @@ class Config {
 			bool mic_stereo; //!< whether to stream stereo or mono from the microphone
       
 			unsigned int speaker_port;    //!< port for streaming speaker samples
-			unsigned int speaker_frame_length; //<! length of frame sent to the speaker (ms)
-			unsigned int speaker_max_delay; //<! maximum delay (ms) during playback
+			unsigned int speaker_frame_length; //!< length of frame sent to the speaker (ms)
+			unsigned int speaker_max_delay; //!< maximum delay (ms) during playback
 
+			//! constructor
 			streaming_config() : mic_port(0), mic_sample_rate(16000),
 			mic_sample_bits(16), mic_stereo(true),
 			speaker_port(0), speaker_frame_length(64),
@@ -240,10 +254,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.37 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.40 $
  * $State: Exp $
- * $Date: 2004/11/12 22:07:39 $
+ * $Date: 2004/12/23 01:47:07 $
  */
 
 #endif
