@@ -189,6 +189,7 @@ namespace ERS7Info {
 		HeadFrButOffset=HeadButOffset,
 		FrontBackButOffset,
 		MiddleBackButOffset,
+		BackButOffset = MiddleBackButOffset,
 		RearBackButOffset,
 		WirelessSwOffset
 	};
@@ -516,11 +517,11 @@ namespace ERS7Info {
  * @brief Defines RobotInfo namespace for ERS-210 models, gives some information about the robot's capabilities, such as joint counts, offsets, names and PID values
  * @author ejt (Creator)
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.20 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.21 $
  * $State: Exp $
- * $Date: 2004/10/19 07:37:09 $
+ * $Date: 2004/12/07 00:46:24 $
  */
 
 #endif
