@@ -29,7 +29,7 @@ class ListMemBuf {
 	//!Allows outside access to index type
 	typedef idx_t index_t;
 	
-	index_t getMaxCapacity() const { return MAX_ENTRIES; } //!<returns the maximum number of objects which can be used at any given time
+	static index_t getMaxCapacity() { return MAX_ENTRIES; } //!<returns the maximum number of objects which can be used at any given time
 	index_t size() const { return cursize; } //!<returns the current number of objects in use
 	index_t countf() const; //!< for debugging, should equal size
 	index_t countb() const; //!< for debugging, should equal size
@@ -334,10 +334,10 @@ ListMemBuf<T,MAX,index_t>::push_free(index_t x) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.8 $
- * $State: Rel $
- * $Date: 2003/09/25 15:31:53 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.9 $
+ * $State: Exp $
+ * $Date: 2004/12/21 20:29:14 $
  */
  
  #endif
