@@ -60,24 +60,25 @@ WorldState::WorldState()
 		else if(strcmp(robotDesignStr,"ERS-7")==0)
 			robotDesign=ERS7Mask;
 		else {
-			cout << "ERROR: Unrecognized model: "<<robotDesignStr<<"\nTrying ERS-210..."<<endl;
-			robotDesign=ERS210Mask;
+			cout << "ERROR: Unrecognized model: "<<robotDesignStr<<"\nDoing the best I can by assuming ERS-7..."<<endl;
+			robotDesign=ERS7Mask;
 		}
 	}
 #else
+	//This is only compiled if we're targeting the local platform
+	//In other words, if target model is an AIBO, simulation mode
 # if TGT_ERS220
 	robotDesign=ERS220Mask;
 # elif TGT_ERS210
 	robotDesign=ERS210Mask;
+# elif TGT_ERS2xx
+#   warning "TGT_ERS2xx can't be determined on non-Aperios - defaulting to TGT_ERS210"
+	robotDesign=ERS210Mask;
 # elif TGT_ERS7
 	robotDesign=ERS7Mask;
-# else //default case, ERS2xx
-#	 if TGT_ERS2xx==0
-#		warning "TGT_<model> undefined - defaulting to TGT_ERS210"
-#  else
-#   warning "TGT_ERS2xx can't be determined on non-Aperios - defaulting to TGT_ERS210"
-#	 endif
-	robotDesign=ERS210Mask;
+# else
+#		warning "TGT_<model> undefined - defaulting to TGT_ERS7"
+	robotDesign=ERS7Mask;
 # endif //model selection
 #endif
 }
@@ -306,7 +307,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 	for(unsigned int i=0; i<evtBuf.size(); i++)
 		er->postEvent(evtBuf[i]);
 	//we don't delete the events in evtBuf - we're handing them off to erouter, which will delete them itself
-	er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif);
+	er->postEvent(EventBase::sensorEGID,SensorSourceID::UpdatedSID,EventBase::statusETID,dif,"SensorSouceID::UpdatedSID",1);
 }
 
 /*! This will cause events to be posted */
@@ -379,7 +380,7 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 		powerFlags[i]=actmasks[i];
 	}
 
-	er->postEvent(EventBase::powerEGID,PowerSourceID::UpdatedSID,EventBase::statusETID,0);
+	er->postEvent(EventBase::powerEGID,PowerSourceID::UpdatedSID,EventBase::statusETID,0,"PowerSourceID::UpdatedSID",1);
 }
 
 #endif //PLATFORM_APERIOS
@@ -409,8 +410,8 @@ void WorldState::chkEvent(std::vector<EventBase*>& evtBuf, unsigned int sid, flo
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.26 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.28 $
  * $State: Exp $
- * $Date: 2004/11/04 19:45:17 $
+ * $Date: 2004/12/22 23:13:02 $
  */
