@@ -197,8 +197,13 @@ SoundManager::Play(Snd_ID id) {
 		}
 		//		}
 		
-		if(sndlist[id].rcr!=NULL)
-			erouter->postEvent(EventBase::audioEGID,playid,EventBase::activateETID,0);
+		if(sndlist[id].rcr!=NULL) {
+			const char * name=sndlist[playlist[playid].snd_id].name;
+			if(name[0]!='\0')
+				erouter->postEvent(EventBase::audioEGID,playid,EventBase::activateETID,0,name,1);
+			else
+				erouter->postEvent(EventBase::audioEGID,playid,EventBase::activateETID,0);
+		}
 	}
 	return playid;
 }
@@ -273,12 +278,16 @@ SoundManager::StopPlay(Play_ID id) {
 	//we start at the back (oldest) since these are the most likely to be removed...
 	for(chanlist_t::index_t it=chanlist.prev(chanlist.end()); it!=chanlist.end(); it=chanlist.prev(it))
 		if(chanlist[it]==id) {
+			std::string name=sndlist[playlist[id].snd_id].name;
 			Release(playlist[id].snd_id);
 			playlist.erase(id);
 			chanlist.erase(it);
 			playlist[id].cumulative+=playlist[id].offset;
 			unsigned int ms=playlist[id].cumulative/(config->sound.sample_bits/8)/(config->sound.sample_rate/1000);
-			erouter->postEvent(EventBase::audioEGID,id,EventBase::deactivateETID,ms);
+			if(name.size()>0)
+				erouter->postEvent(EventBase::audioEGID,id,EventBase::deactivateETID,ms,name,0);
+			else
+				erouter->postEvent(EventBase::audioEGID,id,EventBase::deactivateETID,ms);
 			return;
 		}
 	cout << "SoundManager::StopPlay(): " << id << " does not seem to be playing" << endl;
@@ -510,9 +519,14 @@ SoundManager::ReceivedMsg(const ONotifyEvent& event) {
 			sndlist[msg->id].data=reinterpret_cast<byte*>(rcr->Base()+SoundManagerMsg::MSG_SIZE);
 			//look to see if there's any play's for the sound we just finished loading
 			for(playlist_t::index_t it=playlist.begin();it!=playlist.end();it=playlist.next(it))
-				if(playlist[it].snd_id==msg->id)
+				if(playlist[it].snd_id==msg->id) {
 					//send an event if there are
-					erouter->postEvent(EventBase::audioEGID,it,EventBase::activateETID,0);
+					const char * name=sndlist[playlist[it].snd_id].name;
+					if(name[0]!='\0')
+						erouter->postEvent(EventBase::audioEGID,it,EventBase::activateETID,0,name,1);
+					else
+						erouter->postEvent(EventBase::audioEGID,it,EventBase::activateETID,0);
+				}
 		} break;
 		case SoundManagerMsg::del: {
 			msg->region->RemoveReference();
@@ -655,7 +669,11 @@ SoundManager::endPlay(Play_ID id) {
 		playlist[id].next_id=playlist[next].next_id;
 		playlist.erase(next);
 		unsigned int ms=playlist[id].cumulative/(config->sound.sample_bits/8)/(config->sound.sample_rate/1000);
-		erouter->postEvent(EventBase::audioEGID,id,EventBase::statusETID,ms);
+		const char * name=sndlist[playlist[id].snd_id].name;
+		if(name[0]!='\0')
+			erouter->postEvent(EventBase::audioEGID,id,EventBase::statusETID,ms,name,1);
+		else
+			erouter->postEvent(EventBase::audioEGID,id,EventBase::statusETID,ms);
 		return false;
 	}
 }
@@ -676,10 +694,10 @@ SoundManager::PlayState::PlayState()
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.18 $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.19 $
  * $State: Exp $
- * $Date: 2004/11/04 05:24:03 $
+ * $Date: 2004/12/22 23:13:04 $
  */
 
 
