@@ -56,23 +56,21 @@ SoundPlay::DoInit(const OSystemEvent&)
 	sndman=new ((SoundManager*)soundManagerMemRgn->Base()) SoundManager;
 	sndman->InitAccess(subject[sbjSoundManagerComm]);
 	for(unsigned int i=0; i<config->sound.preload.size(); i++)
-		sndman->LoadFile(config->sound.preload[i].c_str());
+		sndman->LoadFile(config->sound.preload[i]);
 
 	OpenSpeaker();
 	NewSoundVectorData();
 	SetPowerAndVolume();
-
 	return oSUCCESS;
 }
 
 OStatus
 SoundPlay::DoStart(const OSystemEvent&)
 {
-	//OSYSDEBUG(("SoundPlay::DoStart()\n"));
+  //OSYSDEBUG(("SoundPlay::DoStart()\n"));
 
 	ENABLE_ALL_SUBJECT;
 	ASSERT_READY_TO_ALL_OBSERVER;
-
 	return oSUCCESS;
 }
 
@@ -93,7 +91,7 @@ OStatus
 SoundPlay::DoDestroy(const OSystemEvent&)
 {
 	for(unsigned int i=0; i<config->sound.preload.size(); i++)
-		sndman->ReleaseFile(config->sound.preload[i].c_str());
+		sndman->ReleaseFile(config->sound.preload[i]);
 	delete erouter;
 	eventTranslatorQueueMemRgn->RemoveReference();
 	DELETE_ALL_SUBJECT_AND_OBSERVER;
@@ -268,10 +266,10 @@ SoundPlay::FindFreeRegion()
  * either expressed or implied, including but not limited to the
  * implied warranties of fitness for a particular purpose.
  *
- * $Author: ejt $
- * $Name: tekkotsu-2_2_1 $
- * $Revision: 1.13 $
+ * $Author: dst $
+ * $Name: tekkotsu-2_2_2 $
+ * $Revision: 1.14 $
  * $State: Exp $
- * $Date: 2004/01/16 23:55:32 $
+ * $Date: 2004/12/16 22:46:21 $
  */
 
