@@ -1,5 +1,5 @@
 //
-// Copyright 2002 Sony Corporation 
+// Copyright 2002,2003 Sony Corporation 
 //
 // Permission to use, copy, modify, and redistribute this software for
 // non-commercial use is hereby granted.
@@ -10,25 +10,27 @@
 //
 
 #include <OPENR/OSyslog.h>
+#include <OPENR/ODebug.h>
 #include "FtpDTP.h"
-#include "entry.h"
 
 FtpDTP::FtpDTP()
 {
 }
 
 OStatus
-FtpDTP::Initialize(const OID& myoid, const OID& ipoid, void* index)
+FtpDTP::Initialize(const OID& myoid, const antStackRef& ipstack, void* index)
 {
     OSYSDEBUG(("FtpDTP::Initialize()\n"));
 
     myOID        = myoid;
-    ipstackOID   = ipoid;
+    ipstackRef   = ipstack;
     continuation = index;
 
     // initialize FTP connection
     method   = FTP_METHOD_NOOP;
     dataType = FTP_DATA_A;
+    passive  = false;
+    connectPort = FTP_DATA_PORT;
 
     // initialize File System
     ResetFilename();
@@ -41,7 +43,7 @@ FtpDTP::Initialize(const OID& myoid, const OID& ipoid, void* index)
     //
     antEnvCreateSharedBufferMsg sendBufferMsg(FTP_BUFFER_SIZE);
 
-    sendBufferMsg.Call(ipstackOID, sizeof(sendBufferMsg));
+    sendBufferMsg.Call(ipstackRef, sizeof(sendBufferMsg));
     if (sendBufferMsg.error != ANT_SUCCESS) {
         OSYSLOG1((osyslogERROR, "%s : %s[%d] antError %d",
                   "FtpDTP::Initialize()",
@@ -59,7 +61,7 @@ FtpDTP::Initialize(const OID& myoid, const OID& ipoid, void* index)
     //
     antEnvCreateSharedBufferMsg recvBufferMsg(FTP_BUFFER_SIZE);
 
-    recvBufferMsg.Call(ipstackOID, sizeof(recvBufferMsg));
+    recvBufferMsg.Call(ipstackRef, sizeof(recvBufferMsg));
     if (recvBufferMsg.error != ANT_SUCCESS) {
         OSYSLOG1((osyslogERROR, "%s : %s[%d] antError %d",
                   "FtpDTP::Initialize()",
@@ -75,6 +77,44 @@ FtpDTP::Initialize(const OID& myoid, const OID& ipoid, void* index)
     return oSUCCESS;
 }
 
+OStatus
+FtpDTP::Listen()
+{
+    OSYSDEBUG(("FtpDTP::Listen()\n"));
+
+    if (connection.state != CONNECTION_CLOSED) return oFAIL;
+
+    //
+    // Create endpoint
+    //
+    antEnvCreateEndpointMsg tcpCreateMsg(EndpointType_TCP,
+                                         FTP_BUFFER_SIZE * 2);
+
+    tcpCreateMsg.Call(ipstackRef, sizeof(tcpCreateMsg));
+    if (tcpCreateMsg.error != ANT_SUCCESS) {
+        OSYSLOG1((osyslogERROR, "%s : %s[%d] antError %d",
+                  "FtpDTP::Listen()",
+                  "Can't create endpoint",
+                  (int)continuation, tcpCreateMsg.error));
+        return oFAIL;
+    }
+    connection.endpoint = tcpCreateMsg.moduleRef;
+
+    //
+    // Listen
+    //
+    TCPEndpointListenMsg listenMsg(connection.endpoint,
+                                   IP_ADDR_ANY, connectPort);
+    listenMsg.continuation = continuation;
+
+    listenMsg.Send(ipstackRef, myOID,
+                   Extra_Entry[entryListenContforDTP], sizeof(listenMsg));
+    
+    connection.state = CONNECTION_LISTENING;
+
+    return oSUCCESS;
+}
+
 OStatus
 FtpDTP::Connect()
 {
@@ -88,7 +128,7 @@ FtpDTP::Connect()
     antEnvCreateEndpointMsg tcpCreateMsg(EndpointType_TCP,
                                          FTP_BUFFER_SIZE * 2);
 
-    tcpCreateMsg.Call(ipstackOID, sizeof(tcpCreateMsg));
+    tcpCreateMsg.Call(ipstackRef, sizeof(tcpCreateMsg));
     if (tcpCreateMsg.error != ANT_SUCCESS) {
         OSYSLOG1((osyslogERROR, "%s : %s[%d] antError %d",
                   "FtpDTP::Connect()",
@@ -106,7 +146,7 @@ FtpDTP::Connect()
                                      connectIP, connectPort);
     connectMsg.continuation = continuation;
 
-    connectMsg.Send(ipstackOID, myOID,
+    connectMsg.Send(ipstackRef, myOID,
                     Extra_Entry[entryConnectContforDTP], sizeof(connectMsg));
     
     connection.state = CONNECTION_CONNECTING;
@@ -114,6 +154,49 @@ FtpDTP::Connect()
     return oSUCCESS;
 }
 
+bool
+FtpDTP::ListenCont(TCPEndpointListenMsg* listenMsg)
+{
+    OSYSDEBUG(("FtpDTP::ListenCont() %x %d - %x %d\n",
+               listenMsg->lAddress,
+               listenMsg->lPort,
+               listenMsg->fAddress,
+               listenMsg->fPort
+               ));
+
+    if (listenMsg->error != TCP_SUCCESS) {
+        OSYSLOG1((osyslogERROR, "%s : %s %d",
+                  "FtpDTP::ListenCont()",
+                  "FAILED. listenMsg->error", listenMsg->error));
+        Close();
+        return false;
+    }
+
+    connection.state = CONNECTION_CONNECTED;
+
+    switch (method) {
+    case FTP_METHOD_RETR:
+        RetrieveSend();
+        break;
+
+    case FTP_METHOD_STOR:
+        connection.recvSize = 0;
+        Receive();
+        break;
+
+    case FTP_METHOD_LIST:
+        if (!ListSend()) {
+            Close();
+        }
+        break;
+    default:
+        OSYSDEBUG(("not yet\n"));
+        break;
+    }
+
+    return true;
+}
+
 bool
 FtpDTP::ConnectCont(TCPEndpointConnectMsg* connectMsg)
 {
@@ -129,8 +212,7 @@ FtpDTP::ConnectCont(TCPEndpointConnectMsg* connectMsg)
 
     connection.state = CONNECTION_CONNECTED;
 
-		//CHANGE_ET - cast to int to avoid warning
-    switch ((int)method) {
+    switch (method) {
     case FTP_METHOD_RETR:
         RetrieveSend();
         break;
@@ -145,6 +227,7 @@ FtpDTP::ConnectCont(TCPEndpointConnectMsg* connectMsg)
             Close();
         }
         break;
+    default:;//CHANGE_ET added default case to avoid unhandled enumeration warnings
     }
     return true;
 }
@@ -152,16 +235,18 @@ FtpDTP::ConnectCont(TCPEndpointConnectMsg* connectMsg)
 OStatus
 FtpDTP::Send()
 {
-    OSYSDEBUG(("FtpDTP::Send() %d\n", connection.sendSize));
+    OSYSDEBUG(("FtpDTP::Send() "));
 
     if (connection.state != CONNECTION_CONNECTED) return oFAIL;
 
+    OSYSDEBUG(("%d\n", connection.sendSize));
+
     TCPEndpointSendMsg sendMsg(connection.endpoint,
                                connection.sendData,
                                connection.sendSize);
     sendMsg.continuation = continuation;
 
-    sendMsg.Send(ipstackOID, myOID,
+    sendMsg.Send(ipstackRef, myOID,
                  Extra_Entry[entrySendContforDTP],
                  sizeof(TCPEndpointSendMsg));
 
@@ -227,7 +312,7 @@ FtpDTP::Receive()
                                      1, FTP_BUFFER_SIZE);
     receiveMsg.continuation = continuation;
 
-    receiveMsg.Send(ipstackOID, myOID,
+    receiveMsg.Send(ipstackRef, myOID,
                     Extra_Entry[entryReceiveContforDTP], sizeof(receiveMsg));
 
     connection.state = CONNECTION_RECEIVING;
@@ -259,13 +344,14 @@ FtpDTP::ReceiveCont(TCPEndpointReceiveMsg* receiveMsg)
     connection.state = CONNECTION_CONNECTED;
     connection.recvSize = 0;
     Receive();
+
     return false;
 }
 
 OStatus
 FtpDTP::Close()
 {
-    OSYSDEBUG(("FtpDTP::Close()\n"));
+    OSYSDEBUG(("FtpDTP::Close() %d\n", connection.state));
 
     if (connection.state == CONNECTION_CLOSED
         || connection.state == CONNECTION_CLOSING) return oFAIL;
@@ -273,17 +359,21 @@ FtpDTP::Close()
     TCPEndpointCloseMsg closeMsg(connection.endpoint);
     closeMsg.continuation = continuation;
 
-    closeMsg.Send(ipstackOID, myOID,
+    closeMsg.Send(ipstackRef, myOID,
                   Extra_Entry[entryCloseContforDTP], sizeof(closeMsg));
 
     connection.state = CONNECTION_CLOSING;
     ResetFilename();
+    method   = FTP_METHOD_NOOP;
+    dataType = FTP_DATA_A;
+    passive  = false;
+    connectPort = FTP_DATA_PORT;
 
     return oSUCCESS;
 }
 
 void
-FtpDTP::CloseCont(TCPEndpointCloseMsg* /*closeMsg*/)
+FtpDTP::CloseCont(TCPEndpointCloseMsg* /*closeMsg*/) //CHANGE_ET unused parameter
 {
     OSYSDEBUG(("FtpDTP::CloseCont()\n"));
     
