@@ -80,10 +80,10 @@ void StartupBehavior::DoStart() {
 	if(state->robotDesign & WorldState::ERS7Mask)
 		mouthOffset=ERS7Info::MouthOffset;
 	if(mouthOffset!=-1U) {
-		SharedObject<MotionSequenceMC<MotionSequence::SizeTiny> > closeMouth;
-		closeMouth->setPlayTime(3000); //take 3 seconds to close the mouth
+		SharedObject<TinyMotionSequenceMC> closeMouth;
+		closeMouth->advanceTime(3000); //take 3 seconds to close the mouth
 		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
-		closeMouth->setPlayTime(3500); //and hold it for another .5 seconds
+		closeMouth->advanceTime(500); //and hold it for another .5 seconds
 		closeMouth->setOutputCmd(mouthOffset,outputRanges[mouthOffset][MaxRange]);
 		motman->addPrunableMotion(closeMouth,MotionManager::kEmergencyPriority+1);
 		erouter->addTimer(this,1,3250,false);
