@@ -14,7 +14,7 @@ StartupBehavior::SetupFileAccess() {
 	startSubMenu();
 	{ 
 		addItem(new PostureEditor(stop_id));
-		addItem(new RunSequenceControl<MotionSequence::SizeXLarge>("Run Motion Sequence",stop_id));
+		addItem(new RunSequenceControl<XLargeMotionSequenceMC::CAPACITY>("Run Motion Sequence",stop_id));
 		addItem(new PlaySoundControl("Play Sound"));
 		addItem(new WaypointWalkControl());
 		SetupWalkEdit();
