@@ -7,12 +7,14 @@
 #include "Behaviors/Controls/ProfilerCheckControl.h"
 #include "Behaviors/Controls/EventLogger.h"
 #include "Behaviors/Controls/SensorObserverControl.h"
+#include "Behaviors/Controls/BehaviorReportControl.h"
 
 ControlBase*
 StartupBehavior::SetupStatusReports() {
 	addItem(new ControlBase("Status Reports","Displays information about the runtime environment on the console"));
 	startSubMenu();
-	{ 
+	{
+		addItem(new BehaviorReportControl());
 		addItem(new BatteryCheckControl());
 		addItem(new ProfilerCheckControl());
 		addItem(new EventLogger());
