@@ -36,7 +36,8 @@
 #include <algorithm>
 #include "Motion/DynamicMotionSequence.h"
 #include "Motion/Geometry.h"
-#include "Motion/Kinematics.h"
+#include "Motion/OldKinematics.h"
+#include "Shared/Config.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -115,6 +116,7 @@ unsigned int skip=1;
 int main(unsigned int argc, const char** argv) {
 	if(argc<3)
 		return usage(argc,argv);
+	config=new Config("tekkotsu.cfg");
 	unsigned int used=1;
 	bool isRad=true;
 	while(used<argc) {
